@@ -43,7 +43,7 @@ void highlight(GtkWidget *widget, gpointer callback_data);
 int beatcmp(int bar1, float beat1, int bar2, float beat2);
 void read_resultsfile(GtkWidget *widget, gpointer callback_data);
 Results *createnewres(void);
-void note_highlight(struct scoreinfo *si,
+void note_highlight(DenemoGUI *si,
 		    int staff, int sbar, float sbeat, 
 		    int ebar, float ebeat);
 void analysis_gui(GtkMenuItem *menuitem, gpointer data);
@@ -56,8 +56,8 @@ int getfeatures(GtkWidget *combo);
 #ifdef __cplusplus
 extern "C" {
 #endif
-  void denemo_plugin_init(struct scoreinfo *si, PluginData *pd);
-  void denemo_plugin_clean_up(struct scoreinfo *si, PluginData *pd);
+  void denemo_plugin_init(DenemoGUI *si, PluginData *pd);
+  void denemo_plugin_clean_up(DenemoGUI *si, PluginData *pd);
 #ifdef __cplusplus
 }
 #endif
@@ -74,7 +74,7 @@ void cb_itemselect(GtkWidget *item,
   float sbeat, ebeat;
   /*struct callbackdata *cbdata = (struct callbackdata *)data;
   g_print("Item select cbdata si %p\n", cbdata->si);*/
-  struct scoreinfo *si = (struct scoreinfo *)data;
+  DenemoGUI *si = (DenemoGUI *)data;
 
   label = GTK_LABEL(GTK_BIN(item)->child);
   gtk_label_get(label, &name);
@@ -95,7 +95,7 @@ void cb_itemdeselect(GtkWidget *item,
   int staff;
   int sbar,ebar;
   float sbeat, ebeat, similarity;
-  struct scoreinfo *si = (struct scoreinfo *)data;
+  DenemoGUI *si = (DenemoGUI *)data;
   
   label = GTK_LABEL(GTK_BIN(item)->child);
   gtk_label_get(label, &name);
@@ -121,7 +121,7 @@ extern "C" {
 #endif
   //Nasty Global to test removing menu items 
   static GtkWidget *root_menu = NULL;
-  void denemo_plugin_init(struct scoreinfo *si, PluginData *pd)
+  void denemo_plugin_init(DenemoGUI *si, PluginData *pd)
   {
     GtkWidget *menu_item1;
     GtkWidget *menu_item2;
@@ -195,7 +195,7 @@ extern "C" {
   }
 
   /*cleanup function */
-  void denemo_plugin_clean_up(struct scoreinfo *si, PluginData *pd)
+  void denemo_plugin_clean_up(DenemoGUI *si, PluginData *pd)
   {
     g_free(pd->title);
     //Remove analysis submenu 
@@ -216,15 +216,15 @@ void
 unhighlight (GtkWidget *widget,gpointer callback_data)
 {
   staffnode *curstaff;
-  staff *curstaffstruct;
+  DenemoStaff *curstaffstruct;
   measurenode *curmeasure;
   objnode *curobj;
-  mudelaobject *mudelaitem;
-  struct scoreinfo *si = (struct scoreinfo *)callback_data;
+  DenemoObject *mudelaitem;
+  DenemoScore *si = (DenemoScore *)callback_data;
 
   for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
     {
-      curstaffstruct = (staff *)curstaff->data;
+      curstaffstruct = (DenemoStaff *)curstaff->data;
       for (curmeasure = (measurenode *) curstaffstruct->measures;
 	   curmeasure; curmeasure = curmeasure->next)
 	{
@@ -232,7 +232,7 @@ unhighlight (GtkWidget *widget,gpointer callback_data)
 	  for (curobj = (objnode *)curmeasure->data; curobj; 
 	       curobj = curobj->next)
 	    {
-	      mudelaitem = (mudelaobject *)curobj->data;
+	      mudelaitem = (DenemoObject *)curobj->data;
 	      ((chord *)mudelaitem->object)->is_highlighted = FALSE;
 	    }
 	}
@@ -352,7 +352,7 @@ static void highlightnotes(GtkTreeView     *treeview,
   int staff;
   int sbar,ebar;
   float sbeat, ebeat, similarity;
-  struct scoreinfo *si = (struct scoreinfo *)user_data;
+  DenemoGUI *si = (DenemoGUI *)user_data;
 	 
   
   list_store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
@@ -467,7 +467,7 @@ void highlight (GtkWidget *widget ,gpointer callback_data)
   
   int i=1;
 
-  struct scoreinfo *si = (struct scoreinfo *)callback_data;
+  DenemoScore *si = (DenemoScore *)callback_data;
   
   printf("In Highlight, Score is %p\n", si);
   
@@ -565,21 +565,21 @@ void highlight (GtkWidget *widget ,gpointer callback_data)
 #endif
 
 void
-note_highlight (struct scoreinfo *si,
+note_highlight (DenemoGUI *si,
 		int mstaff, int sbar, float sbeat, 
 		int ebar, float ebeat)
 {
   staffnode *curstaff = NULL;
-  staff *curstaffstruct = NULL;
+  DenemoStaff *curstaffstruct = NULL;
   measurenode *curmeasure = NULL;
   objnode *curobj = NULL;
-  mudelaobject *mudelaitem = NULL;
+  DenemoObject *mudelaitem = NULL;
   gint bar;
   gfloat beat;
   
  
-  curstaff = (staffnode *) g_list_nth(si->thescore, mstaff-1);
-  curstaffstruct = (staff *) curstaff->data;
+  curstaff = (staffnode *) g_list_nth(si->si->thescore, mstaff-1);
+  curstaffstruct = (DenemoStaff *) curstaff->data;
   for (curmeasure = (measurenode *) curstaffstruct->measures,
 	 bar = 1; curmeasure; curmeasure = curmeasure->next, bar++)
     {
@@ -592,7 +592,7 @@ note_highlight (struct scoreinfo *si,
 #ifdef DEBUG
 	      g_print ("Bar %d, Beat %f\n", bar, beat);
 #endif /*DEBUG*/
-	      mudelaitem = (mudelaobject *)curobj->data;
+	      mudelaitem = (DenemoObject *)curobj->data;
 	      if (beatcmp(bar, beat, sbar, sbeat) >= 0
 		  || beatcmp (bar, beat, ebar, ebeat) >= 0)
 		{
