@@ -6,8 +6,8 @@ extern "C"
 {
 #endif
 	
-	void denemo_plugin_init(struct scoreinfo *si, PluginData *pd);
-	void denemo_plugin_clean_up(struct scoreinfo *si, PluginData *pd);
+	void denemo_plugin_init(DenemoGUI *si, PluginData *pd);
+	void denemo_plugin_clean_up(DenemoGUI *si, PluginData *pd);
 #ifdef __cplusplus
 }
 #endif
@@ -16,7 +16,7 @@ extern "C"
 extern "C" 
 {
 #endif
-	void denemo_plugin_init(struct scoreinfo *si, PluginData *pd)
+	void denemo_plugin_init(DenemoGUI *si, PluginData *pd)
 	{
 		/*Set plugin Name in list and increment counter*/
 		pd->title = g_strdup("Rumour");
@@ -24,7 +24,7 @@ extern "C"
 		si->plugincounter++;
 	}
 	
-   void denemo_plugin_clean_up(struct scoreinfo *si, PluginData *pd)
+   void denemo_plugin_clean_up(DenemoGUI *si, PluginData *pd)
 	{
 		g_free(pd->title);
 		
