@@ -13,11 +13,11 @@ enum articulationcallbackaction
 { GENERAL, STRING, ORGAN };
 
 
-int set_articulation(gchar *string, mudelaobject *obj);
+void set_articulation(gchar *string, DenemoObject *obj);
 
 
-void toggle_articulation_palette (GtkAction *action, struct scoreinfo *si);
-void popup_articulation_palette (GtkAction *action, struct scoreinfo *si);
-void articulation_dialog (GtkAction *action, struct scoreinfo *si);
+void toggle_articulation_palette (GtkAction *action, DenemoGUI *si);
+void popup_articulation_palette (GtkAction *action, DenemoGUI *si);
+void articulation_dialog (GtkAction *action, DenemoGUI *si);
 GList* insert_ornament_list(enum ornament orn, GList *list);
 #endif
