@@ -20,7 +20,7 @@ static gchar *string_barlines[6] = { "Ordinary", "Double",
 
 struct callbackdata
 {
-  struct scoreinfo *si;
+  DenemoScore *si;
   GtkWidget *combo;
 };
 
@@ -54,11 +54,11 @@ barlinefromname (gchar * thetext)
 /**
  * Dialog for inserting the barlines
  * @param action the gtk action emitted by the menu item
- * @param si the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-insert_barline (GtkAction * action, gpointer data)
+insert_barline (GtkAction * action, DenemoGUI * gui)
 {
   GtkWidget *dialog;
   GtkWidget *label;
@@ -67,7 +67,7 @@ insert_barline (GtkAction * action, gpointer data)
   GtkWidget *cancelbutton;
   GList *list = NULL;
   static struct callbackdata cbdata;
-  struct scoreinfo *si = (struct scoreinfo *) data;
+
   int i = 0;
 
   dialog = gtk_dialog_new ();
@@ -92,7 +92,7 @@ insert_barline (GtkAction * action, gpointer data)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area),
 		      okbutton, TRUE, TRUE, 0);
 
-  cbdata.si = si;
+  cbdata.si = gui->si;
   cbdata.combo = combobox;
   /* Signal connection */
   gtk_signal_connect (GTK_OBJECT (okbutton), "clicked",
@@ -132,7 +132,7 @@ void
 add_barline (GtkWidget * widget, gpointer data)
 {
   struct callbackdata *cbdata = (struct callbackdata *) data;
-  struct scoreinfo *si = cbdata->si;
+  DenemoScore *si = cbdata->si;
 
   gchar *thetext =
     (gchar *)
@@ -147,12 +147,12 @@ add_barline (GtkWidget * widget, gpointer data)
  * @param bartype	numeric representation of the barline
  * @return the new barline
  */
-mudelaobject *
+DenemoObject *
 newbarline (enum barline_type bartype)
 {
-  mudelaobject *newobj;
+  DenemoObject *newobj;
   barline *obj = (barline *) g_malloc (sizeof (barline));
-  newobj = (mudelaobject *) g_malloc (sizeof (mudelaobject));
+  newobj = (DenemoObject *) g_malloc (sizeof (DenemoObject));
   newobj->type = BARLINE;
   newobj->isinvisible = FALSE;
   obj->type = bartype;
