@@ -3,9 +3,9 @@
 
 
 #include <denemo/denemo.h>
-void insert_barline (GtkAction * action, gpointer data);
+void insert_barline (GtkAction * action, DenemoGUI *gui);
 
-mudelaobject *newbarline(enum barline_type type);
+DenemoObject *newbarline(enum barline_type type);
 
 void add_barline(GtkWidget *widget, gpointer data);
 enum barline_type barlinefromname (gchar * thetext);
