@@ -15,8 +15,8 @@
 
 #include <denemo/denemo.h>
 
-void addbookmark(GtkAction *action, struct scoreinfo *si);
-void gotobookmark(GtkAction *action, struct scoreinfo *si);
+void addbookmark(GtkAction *action,DenemoGUI *gui);
+void gotobookmark(GtkAction *action, DenemoGUI *gui);
 
 
 #endif
