@@ -10,9 +10,9 @@
 #ifndef CHANGENOTEHEAD_H
 #define CHANGENOTEHEAD_H
 
-void insertnotehead(GtkWidget *widget, gpointer data);
+void insertnotehead(DenemoScore *si,gchar *noteheadstring);
 gint texttohead(gchar *text);
 void set_notehead
-(GtkAction *acton, gpointer callback_data);
+(GtkAction *acton, DenemoGUI *gui);
 
 #endif
