@@ -29,9 +29,9 @@ calcheight (gpointer data, gpointer user_data)
  *
  */
 void
-newclefify (mudelaobject * thechord, gint dclef)
+newclefify (DenemoObject * thechord, gint dclef)
 {
-  g_list_foreach (((chord *) thechord->object)->tones, calcheight,
+  g_list_foreach (((chord *) thechord->object)->notes, calcheight,
 		  GINT_TO_POINTER (dclef));
   ((chord *) thechord->object)->highesty =
     calculateheight (((chord *) thechord->object)->highestpitch, dclef);
@@ -41,11 +41,11 @@ newclefify (mudelaobject * thechord, gint dclef)
 
 /**
  *  This function goes through a chord and checks to see how its notes are
- * laid out, and if it will have to push the display of any tones to the
+ * laid out, and if it will have to push the display of any notes to the
  * "wrong" side of the staff as a result 
  */
 void
-findreversealigns (mudelaobject * thechord)
+findreversealigns (DenemoObject * thechord)
 {
   GList *current;
   GList *previous;
@@ -53,11 +53,11 @@ findreversealigns (mudelaobject * thechord)
   note *prevnote;
 
   ((chord *) thechord->object)->is_reversealigned = FALSE;
-  if (((chord *) thechord->object)->tones)
+  if (((chord *) thechord->object)->notes)
     if (((chord *) thechord->object)->is_stemup)
       {
 	/* note clusters are painted left-right from bottom to top */
-	previous = ((chord *) thechord->object)->tones;
+	previous = ((chord *) thechord->object)->notes;
 	current = previous->next;
 	prevnote = (note *) previous->data;
 	prevnote->reversealign = FALSE;
@@ -79,7 +79,7 @@ findreversealigns (mudelaobject * thechord)
       {
 	/* the stem's down
 	 * note clusters are painted right-left from top to bottom */
-	previous = g_list_last (((chord *) thechord->object)->tones);
+	previous = g_list_last (((chord *) thechord->object)->notes);
 	current = previous->prev;
 	prevnote = (note *) previous->data;
 	prevnote->reversealign = FALSE;
@@ -105,22 +105,22 @@ findreversealigns (mudelaobject * thechord)
  * and do the basic initialisation
  *
  */
-mudelaobject *
+DenemoObject *
 newchord (gint baseduration, gint numdots, int tied)
 {
-  mudelaobject *thechord = (mudelaobject *) g_malloc0 (sizeof (mudelaobject));
+  DenemoObject *thechord = (DenemoObject *) g_malloc0 (sizeof (DenemoObject));
   chord *newchord = (chord *) g_malloc0 (sizeof (chord));
   thechord->type = CHORD;
   thechord->isinvisible = FALSE;
 
-  newchord->tones = NULL;
+  newchord->notes = NULL;
   newchord->dynamics = NULL;
   newchord->highestpitch = G_MININT;
   newchord->lowestpitch = G_MAXINT;
   newchord->baseduration = baseduration;
   newchord->numdots = numdots;
   newchord->sum_mid_c_offset = 0;
-  newchord->numtones = 0;
+  newchord->numnotes = 0;
   newchord->is_tied = tied;
   newchord->is_reversealigned = FALSE;
   newchord->slur_begin_p = FALSE;
@@ -139,7 +139,7 @@ newchord (gint baseduration, gint numdots, int tied)
   newchord->center_lyric = FALSE;
   newchord->lyric = NULL;
   newchord->figure = NULL;
-  newchord->ornamentlist=NULL;
+  newchord->ornamentlist = NULL;
   thechord->object = newchord;
 
   set_basic_numticks (thechord);
@@ -150,20 +150,37 @@ newchord (gint baseduration, gint numdots, int tied)
 
   return thechord;
 }
-
+DenemoObject *
+dnm_newchord (gint baseduration, gint numdots, int tied){
+		newchord (baseduration, numdots, tied);
+}
 /**
- * Set the invisible flag for the mudelaobject
+ * Set the invisible flag for the DenemoObject
  * @param thechord object to make invisible
  * @return the chord
  */
-mudelaobject *
-hidechord (mudelaobject * thechord)
+DenemoObject *
+hidechord (DenemoObject * thechord)
 {
   thechord->isinvisible = TRUE;
 
   return thechord;
 }
 
+
+/**
+ * adds an ornament to the given note
+ * @param obj the DenemoObject to add the ornament to.
+ * @param orn the ornament type to add
+ */
+void
+addornament (DenemoObject * obj, Ornament orn)
+{
+  if (obj && obj->type == CHORD && ((chord *) obj->object)->notes)
+    ((chord *) obj->object)->ornamentlist =
+      insert_ornament_list (orn, ((chord *) obj->object)->ornamentlist);
+}
+
 /**
  * compare current note with pitch to be added
  * 
@@ -195,29 +212,56 @@ insertcomparefunc (gconstpointer a, gconstpointer b)
   return anote->mid_c_offset - bnote->mid_c_offset;
 }
 
+/* modify the pitch of the note of a one note chord.
+   (for multi-note chords delete and add a note, do not use this).
+*/
+void modify_note(chord *thechord, gint mid_c_offset, gint enshift, gint dclef) {
+  note *thenote = (note*)(thechord->notes->data);
+  thenote->mid_c_offset = mid_c_offset;
+  thenote->enshift = enshift;
+  thenote->y = calculateheight (mid_c_offset, dclef);
+  thechord->sum_mid_c_offset = mid_c_offset;//Damned difficult to track this down - will not work if there are >1 notes in chord
+  thechord->highestpitch = mid_c_offset;
+  thechord->highesty =
+    calculateheight (mid_c_offset, dclef);
+  thechord->lowestpitch = mid_c_offset;
+  thechord->lowesty =
+    calculateheight (mid_c_offset, dclef); 
+}
+
+/* Allocate a new note structure initializing the fields
+ * caller must g_free
+ */
+
+static note *new_note(gint mid_c_offset, gint enshift, gint dclef) {
+  note *newnote;
+  newnote = (note *) g_malloc0 (sizeof (note));
+  newnote->mid_c_offset = mid_c_offset;
+  newnote->enshift = enshift;
+  newnote->y = calculateheight (mid_c_offset, dclef);
+  newnote->reversealign = FALSE;
+  newnote->noteheadtype = DENEMO_NORMAL_NOTEHEAD;
+  return newnote;
+}
 /** 
- * Add tone to the current chord
- * The tone will not get added if it is
+ * Add note to the current chord
+ * The note will not get added if it is
  * present already
  */
 void
-addtone (mudelaobject * thechord, gint mid_c_offset, gint enshift, gint dclef)
+addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift, gint dclef)
 {
   note *newnote;
 
   if (!g_list_find_custom
-      (((chord *) thechord->object)->tones, GINT_TO_POINTER (mid_c_offset),
+      (((chord *) thechord->object)->notes, GINT_TO_POINTER (mid_c_offset),
        findcomparefunc))
     {
       /* A-ha! The note isn't already in the chord */
-      newnote = (note *) g_malloc0 (sizeof (note));
-      newnote->mid_c_offset = mid_c_offset;
-      newnote->enshift = enshift;
-      newnote->reversealign = FALSE;
-      newnote->y = calculateheight (mid_c_offset, dclef);
-      newnote->noteheadtype = DENEMO_NORMAL_NOTEHEAD;
-      ((chord *) thechord->object)->tones =
-	g_list_insert_sorted (((chord *) thechord->object)->tones, newnote,
+      newnote = new_note(mid_c_offset, enshift, dclef);
+      
+      ((chord *) thechord->object)->notes =
+	g_list_insert_sorted (((chord *) thechord->object)->notes, newnote,
 			      insertcomparefunc);
       if (mid_c_offset > ((chord *) thechord->object)->highestpitch)
 	{
@@ -232,22 +276,25 @@ addtone (mudelaobject * thechord, gint mid_c_offset, gint enshift, gint dclef)
 	    calculateheight (mid_c_offset, dclef);
 	}
       ((chord *) thechord->object)->sum_mid_c_offset += mid_c_offset;
-      ((chord *) thechord->object)->numtones++;
+      ((chord *) thechord->object)->numnotes++;
     }
 }
 
+void dnm_addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift, gint dclef) {
+	addtone (thechord, mid_c_offset, enshift,dclef);
+}
 /** 
  * This function finds the node of the closest chord tone to n; in the
- * case of equally distant chord tones, it'll select the higher tones
+ * case of equally distant chord notes, it'll select the higher notes
  * of the two 
  */
 
 /* I don't think that I could have quite done this with a g_list_find_custom */
 
-GList *
-findclosest (GList * tones, gint n)
+static GList *
+findclosest (GList * notes, gint n)
 {
-  GList *cur_tnode = tones;
+  GList *cur_tnode = notes;
   GList *next_tnode;
   note *cur_tone;
   note *next_tone;
@@ -279,18 +326,23 @@ findclosest (GList * tones, gint n)
     }				/* End for loop */
 }
 
+objnode *nearestnote (DenemoObject * thechord, gint mid_c_offset) {
+  if( thechord && thechord->object  && thechord->type==CHORD && ((chord *) thechord->object)->notes)
+    return findclosest (((chord *) thechord->object)->notes, mid_c_offset);
+  else return NULL;
+}
 
 /**
  * Remove tone from current chord
  *
  */
 void
-removetone (mudelaobject * thechord, gint mid_c_offset, gint dclef)
+removetone (DenemoObject * thechord, gint mid_c_offset, gint dclef)
 {
   GList *tnode;			/* Tone node to remove */
   note *tone;
 
-  tnode = findclosest (((chord *) thechord->object)->tones, mid_c_offset);
+  tnode = findclosest (((chord *) thechord->object)->notes, mid_c_offset);
   if (tnode)
     {
       tone = (note *) tnode->data;
@@ -326,23 +378,43 @@ removetone (mudelaobject * thechord, gint mid_c_offset, gint dclef)
        * actually free stuff */
 
       g_free (tone);
-      ((chord *) thechord->object)->tones =
-	g_list_remove_link (((chord *) thechord->object)->tones, tnode);
+      ((chord *) thechord->object)->notes =
+	g_list_remove_link (((chord *) thechord->object)->notes, tnode);
       g_list_free_1 (tnode);
     }
 }
 
 /**
- * Alter the pitch of the currentchord by setting
- * the accidental value
+ * Set the accidental of note closest to mid_c_offset in
+ * the currentchord accidental = -2 ... +2 for double flat to double sharp
  */
 void
-shiftpitch (mudelaobject * thechord, gint mid_c_offset, gint is_sharpening)
+changeenshift (DenemoObject * thechord, gint mid_c_offset, gint accidental)
+{
+  GList *tnode;			/* note node to inflect */
+  note *tone;
+  tnode = findclosest (((chord *) thechord->object)->notes, mid_c_offset);
+  if (tnode)
+    {
+      tone = (note *) tnode->data;
+      tone->enshift = accidental;
+    }
+}
+
+
+/**
+ * Alter the pitch the  note closest to mid_c_offset in
+ * the currentchord by setting
+ * the accidental value 
+ * one sharper or flatter subject to a limit of double sharp/flat
+ */
+void
+shiftpitch (DenemoObject * thechord, gint mid_c_offset, gint is_sharpening)
 {
   GList *tnode;			/* Tone node to inflect */
   note *tone;
 
-  tnode = findclosest (((chord *) thechord->object)->tones, mid_c_offset);
+  tnode = findclosest (((chord *) thechord->object)->notes, mid_c_offset);
   if (tnode)
     {
       tone = (note *) tnode->data;
@@ -353,12 +425,13 @@ shiftpitch (mudelaobject * thechord, gint mid_c_offset, gint is_sharpening)
     }
 }
 
+
 /**
  * Change the duration of the current chord
  *
  */
 void
-changedur (mudelaobject * thechord, gint baseduration, gint numdots)
+changedur (DenemoObject * thechord, gint baseduration, gint numdots)
 {
   ((chord *) thechord->object)->baseduration = baseduration;
   ((chord *) thechord->object)->numdots = numdots;
@@ -370,7 +443,7 @@ changedur (mudelaobject * thechord, gint baseduration, gint numdots)
  *
  */
 void
-changenumdots (mudelaobject * thechord, gint number)
+changenumdots (DenemoObject * thechord, gint number)
 {
   ((chord *) thechord->object)->numdots =
     MAX (((chord *) thechord->object)->numdots + number, 0);
@@ -381,10 +454,18 @@ changenumdots (mudelaobject * thechord, gint number)
  * Free the current chord
  */
 void
-freechord (mudelaobject * thechord)
+freechord (DenemoObject * thechord)
 {
-  g_list_foreach (((chord *) thechord->object)->tones, freeit, NULL);
-  g_list_free (((chord *) thechord->object)->tones);
+  g_list_foreach (((chord *) thechord->object)->notes, freeit, NULL);
+  g_list_free (((chord *) thechord->object)->notes);
+  g_list_free(((chord *) thechord->object)->dynamics);
+  g_list_free(((chord *) thechord->object)->ornamentlist);
+  if(((chord *) thechord->object)->lyric)
+    g_string_free(((chord *) thechord->object)->lyric, FALSE);
+  /* tone_node does not belong to the chord but belongs instead to the pitch recognition system */
+  if(((chord *) thechord->object)->is_figure && ((chord *) thechord->object)->figure)
+    g_string_free(((chord *) thechord->object)->figure, FALSE);
+  
   g_free (thechord);
 }
 
@@ -392,17 +473,17 @@ freechord (mudelaobject * thechord)
  * Clone the current chord
  * used in the cut/copy/paste routine
  */
-mudelaobject *
-clone_chord (mudelaobject * thechord)
+DenemoObject *
+clone_chord (DenemoObject * thechord)
 {
-  mudelaobject *ret = (mudelaobject *) g_malloc0 (sizeof (mudelaobject));
+  DenemoObject *ret = (DenemoObject *) g_malloc0 (sizeof (DenemoObject));
   GList *curtone;
   note *newnote;
   chord *clonedchord = (chord *) g_malloc0 (sizeof (chord));
   /* I'd use a g_list_copy here, only that won't do the deep copy of
    * the list data that I'd want it to */
-  memcpy ((mudelaobject *) ret, (mudelaobject *) thechord,
-	  sizeof (mudelaobject));
+  memcpy ((DenemoObject *) ret, (DenemoObject *) thechord,
+	  sizeof (DenemoObject));
 
   ret->object = NULL;
 
@@ -412,24 +493,37 @@ clone_chord (mudelaobject * thechord)
 
   memcpy ((chord *) clonedchord, (chord *) thechord->object, sizeof (chord));
 
+#if 0
+  //this would have to clone the list to work, else both notes share the same list and deleting one should
+  // leave the other dangling.
   if (!((chord *) thechord->object)->dynamics)
     clonedchord->dynamics = NULL;
   else
     clonedchord->dynamics = ((chord *) thechord->object)->dynamics;
+#else
+  clonedchord->dynamics = NULL;
+#endif
+  clonedchord->ornamentlist = NULL;
+  clonedchord->tone_node = NULL;
+  clonedchord->figure = NULL;
+  clonedchord->is_figure = FALSE;
+  clonedchord->lyric = NULL;
 
-  clonedchord->tones = NULL;
-  for (curtone = ((chord *) thechord->object)->tones;
+
+
+  clonedchord->notes = NULL;
+  for (curtone = ((chord *) thechord->object)->notes;
        curtone; curtone = curtone->next)
     {
       newnote = (note *) g_malloc0 (sizeof (note));
       memcpy (newnote, (note *) curtone->data, sizeof (note));
-      clonedchord->tones = g_list_append (clonedchord->tones, newnote);
+      clonedchord->notes = g_list_append (clonedchord->notes, newnote);
     }
   ret->object = (chord *) clonedchord;
-#ifdef DEBUG
-  g_print ("Chord Base dur %d \tCloned Note base dur %d\n",
-	   ((chord *) thechord->object)->baseduration,
-	   ((chord *) ret->object)->baseduration);
-#endif
+  /*#ifdef DEBUG
+     g_print ("Chord Base dur %d \tCloned Note base dur %d\n",
+     ((chord *) thechord->object)->baseduration,
+     ((chord *) ret->object)->baseduration);
+     #endif */
   return ret;
 }
