@@ -45,9 +45,9 @@ static ClefInfo clef_info[] = {
  * calls clef change with the INSERT argument
  */
 void
-clef_change_insert (GtkAction * action, scoreinfo *si)
+clef_change_insert (GtkAction * action, DenemoGUI * si)
 {
-  clef_change ( si, INSERT);
+  clef_change (si, INSERT);
 }
 
 /**
@@ -55,25 +55,28 @@ clef_change_insert (GtkAction * action, scoreinfo *si)
  * calls clef change with the CHANGEINITIAL argument
  */
 void
-clef_change_initial (GtkAction * action, scoreinfo *si)
+clef_change_initial (GtkAction * action, DenemoGUI * si)
 {
   clef_change (si, CHANGEINITIAL);
 }
 
-void setinitialclef(scoreinfo *si, staff *curstaffstruct, enum clefs clef)
+void
+dnm_setinitialclef (DenemoScore * si, DenemoStaff * curstaffstruct,
+		    enum clefs clef)
 {
- 	curstaffstruct->sclef = clef;
-	find_leftmost_staffcontext (curstaffstruct, si);
-	fixnoteheights (curstaffstruct);
-	find_xes_in_all_measures (si);
+  curstaffstruct->sclef = clef;
+  find_leftmost_staffcontext (curstaffstruct, si);
+  fixnoteheights (curstaffstruct);
+  find_xes_in_all_measures (si);
 }
+
 /**
  * Clef change dialog, two modes
  * 1,  Set Initial clef
  * 2,  Insert Clef Change
  */
 void
-clef_change (scoreinfo *si, actiontype action)
+clef_change (DenemoGUI * gui, actiontype action)
 {
   GtkWidget *dialog;
   GtkWidget *label;
@@ -81,19 +84,22 @@ clef_change (scoreinfo *si, actiontype action)
   GtkListStore *list_store;
   GtkTreeIter iter;
   GtkCellRenderer *renderer;
-  staff *curstaffstruct = (staff *) si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
   int i;
-
-  if (si->lily_file && action == CHANGEINITIAL)
-    return;			/* no code for this yet - just edit textually */
-
-  dialog = gtk_dialog_new_with_buttons (((action == CHANGEINITIAL) ? _("Set Clef") : _("Insert clef change")), NULL,	/* parent window */
-					(GtkDialogFlags)
-					(GTK_DIALOG_MODAL |
-					 GTK_DIALOG_DESTROY_WITH_PARENT),
-					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-					GTK_STOCK_CANCEL, GTK_STOCK_CANCEL,
-					NULL);
+  
+  if (gui->si->lily_file && action == CHANGEINITIAL)
+    return;		       /* no code for this yet - just edit textually */
+  
+  dialog = 
+    gtk_dialog_new_with_buttons (((action == CHANGEINITIAL) ? 
+				  _("Set Clef") : _("Insert clef change")), 
+				 NULL,	/* parent window */
+				 (GtkDialogFlags)
+				 (GTK_DIALOG_MODAL |
+				  GTK_DIALOG_DESTROY_WITH_PARENT),
+				 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+				 GTK_STOCK_CANCEL, GTK_STOCK_CANCEL,
+				 NULL);
 
 
   label = gtk_label_new (_("Select desired clef"));
@@ -124,8 +130,8 @@ clef_change (scoreinfo *si, actiontype action)
 
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 		      combobox, TRUE, TRUE, 0);
-  //gtk_entry_set_activates_default(GTK_ENTRY(GTK_COMBO(combobox)->entry), TRUE);
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
   gtk_widget_show_all (dialog);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
@@ -137,16 +143,16 @@ clef_change (scoreinfo *si, actiontype action)
 
       if (action == CHANGEINITIAL)
 	{
-	  setinitialclef(si,curstaffstruct, clef);
-	  displayhelper(si);
+	  dnm_setinitialclef (gui->si, curstaffstruct, clef);
+
 
 	}
       else
 	{
-	  object_insert (si, newclefobj (clef));
+	  object_insert (gui->si, dnm_newclefobj (clef));
+
 	}
+      displayhelper (gui);
     }
   gtk_widget_destroy (dialog);
 }
-
- 
