@@ -15,21 +15,22 @@
 #include "staffops.h"
 
 /**
- * This function finds the first mudelaobject of type thetype before measure
- * curmeasure. It returns NULL if it was unable to find such a mudelaobject 
+ * This function finds the first DenemoObject of type thetype before measure
+ * curmeasure. It returns NULL if it was unable to find such a DenemoObject 
  * 
  * @param curmeasure the current measure to search
- * @param thetype type of mudelaobject to find
- * @return the first mudelaobject of type the type
+ * @param thetype type of DenemoObject to find
+ * @return the first DenemoObject of type the type
  */
-static mudelaobject *
+static DenemoObject *
 find_context (measurenode * curmeasure, gint thetype)
 {
   objnode *curobj;
-
-  curmeasure = curmeasure->prev;
-  if (!curmeasure)
+  if (curmeasure && curmeasure->prev)
+    curmeasure = curmeasure->prev;
+  else
     return NULL;
+
   curobj = lastobjnode (curmeasure);
   while (1)
     {
@@ -40,8 +41,8 @@ find_context (measurenode * curmeasure, gint thetype)
 	  curmeasure = curmeasure->prev;
 	  curobj = lastobjnode (curmeasure);
 	}
-      if (((mudelaobject *) curobj->data)->type == thetype)
-	return (mudelaobject *) curobj->data;
+      if (((DenemoObject *) curobj->data)->type == thetype)
+	return (DenemoObject *) curobj->data;
       else
 	curobj = curobj->prev;
     }
@@ -49,18 +50,18 @@ find_context (measurenode * curmeasure, gint thetype)
 
 /**
  * Finds the first occurrences of the clef, keysig and timesig of the 
- * current staff 
+ * current staff  inserting them into the passed CURSTAFFSTRUCT
  * 
  * @param curstaffstruct the current staff
  * @param si the scoreinfo structure
  * @return none
  */
 void
-find_leftmost_staffcontext (staff * curstaffstruct, scoreinfo *si)
+find_leftmost_staffcontext (DenemoStaff * curstaffstruct, DenemoScore * si)
 {
   measurenode *leftmeasure = g_list_nth (curstaffstruct->measures,
 					 si->leftmeasurenum - 1);
-  mudelaobject *obj;
+  DenemoObject *obj;
 
   if ((obj = find_context (leftmeasure, CLEF)))
     curstaffstruct->leftmost_clefcontext = ((clef *) obj->object)->type;
@@ -70,8 +71,10 @@ find_leftmost_staffcontext (staff * curstaffstruct, scoreinfo *si)
     curstaffstruct->leftmost_keysigcontext = ((keysig *) obj->object)->number;
   else
     curstaffstruct->leftmost_keysigcontext = curstaffstruct->skey;
-  initkeyaccs (curstaffstruct->leftmost_keyaccs,
-	       curstaffstruct->leftmost_keysigcontext);
+  dnm_setinitialkeysig  (curstaffstruct, curstaffstruct->leftmost_keysigcontext,
+      curstaffstruct->skey_isminor);
+  /* initkeyaccs (curstaffstruct->leftmost_keyaccs,
+     curstaffstruct->leftmost_keysigcontext);*/
   curstaffstruct->leftmost_keywidth =
     draw_key (NULL, NULL, 0, 0, curstaffstruct->leftmost_keysigcontext,
 	      0, 0, FALSE);
@@ -101,15 +104,16 @@ find_leftmost_staffcontext (staff * curstaffstruct, scoreinfo *si)
  * @return none
  */
 void
-find_leftmost_allcontexts (scoreinfo *si)
+find_leftmost_allcontexts (DenemoScore * si)
 {
   staffnode *curstaff = si->thescore;
 
   si->maxkeywidth = G_MININT;
   for (; curstaff; curstaff = curstaff->next)
     {
-      find_leftmost_staffcontext ((staff *) curstaff->data, si);
+      find_leftmost_staffcontext ((DenemoStaff *) curstaff->data, si);
       si->maxkeywidth = MAX (si->maxkeywidth,
-			     ((staff *) curstaff->data)->leftmost_keywidth);
+			     ((DenemoStaff *) curstaff->data)->
+			     leftmost_keywidth);
     }
 }
