@@ -9,7 +9,7 @@
 
 #include <denemo/denemo.h>
 
-void find_leftmost_staffcontext (staff * curstaffstruct,
-				 scoreinfo *si);
+void find_leftmost_staffcontext (DenemoStaff * curstaffstruct,
+				 DenemoScore *si);
 
-void find_leftmost_allcontexts (scoreinfo *si);
+void find_leftmost_allcontexts (DenemoScore *si);
