@@ -2,16 +2,16 @@
 #define CSOUNDPLAYBACK_H
 
 #include <denemo/denemo.h>
-
+/*
 struct cs_callback
 {
 	GtkWidget *entry;
 	GtkWidget *dialog;
-	scoreinfo *si;
+	DenemoGUI *gui;
 	
 };
-
-void csoundplayback(GtkAction *action, scoreinfo *si);
+*/
+void csoundplayback(GtkAction *action, DenemoGUI *gui);
 void chooseorcfile (GtkWidget * widget, struct cs_callback *data);
 
 #endif
