@@ -10,14 +10,14 @@
 
 gint
 scorearea_configure_event (GtkWidget * widget, GdkEventConfigure * event,
-			   struct scoreinfo *si);
+			    DenemoGUI *si);
 
 gint
 scorearea_expose_event (GtkWidget * widget, GdkEventExpose * event,
 			gpointer data);
 
 void
-draw_measures (GtkWidget * widget, struct scoreinfo *si);
+draw_measures (GtkWidget * widget, DenemoGUI *si);
 
 void
-display_string (gchar *str, struct scoreinfo *si);
+display_string (gchar *str,  DenemoGUI *si);
