@@ -5,7 +5,7 @@
  * (c) 1999-2005 Matthew Hiller
  */
 
-#include <gtk/gtk.h>
+
 #include <denemo/denemo.h> 
 
 
@@ -44,11 +44,11 @@ draw_timesig (GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
 
 void
 draw_tupbracket (GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-		 gint xx, gint y, mudelaobject *theobj);
+		 gint xx, gint y, DenemoObject *theobj);
 
 void
-draw_cursor (GdkPixmap *pixmap, struct scoreinfo *si,
-	     gint xx, gint y, gint dclef);
+draw_cursor (GdkPixmap *pixmap, DenemoScore *si,
+	     gint xx, gint y, input_mode mode, gint dclef);
 
 void
 draw_accidental (GdkPixmap *pixmap, GdkGC *gc,
@@ -60,19 +60,19 @@ draw_selection (GdkPixmap *pixmap, GdkGC *gc, gint x1, gint y1,
 
 void
 draw_stem_directive (GdkPixmap * pixmap, GdkGC * gc, GdkFont *font,
-		     gint xx, gint y, mudelaobject * theobj);
+		     gint xx, gint y, DenemoObject * theobj);
 
 void
 draw_dynamic(GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-	      gint xx, gint y, mudelaobject *theobj);
+	      gint xx, gint y, DenemoObject *theobj);
 
 void
 draw_lily_dir(GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-	      gint xx, gint y, mudelaobject *theobj);
+	      gint xx, gint y, DenemoObject *theobj);
 
 void
 draw_gracebracket (GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-		   gint xx, gint y, mudelaobject *theobj);
+		   gint xx, gint y, DenemoObject *theobj);
 
 
 gint calc_offset(chord thechord, gint stemdir);
@@ -80,9 +80,13 @@ void draw_articulations(GdkPixmap *pixmap, GdkGC *gc,
 			chord thechord, gint xx, gint y);
 
 void draw_lyric(GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-                gint xx, gint y, mudelaobject *theobj);
+                gint xx, gint y, DenemoObject *theobj);
 
 void draw_figure(GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
-                        gint xx, gint y, mudelaobject *theobj);
+                        gint xx, gint y, DenemoObject *theobj);
+
+void draw_fakechord(GdkPixmap *pixmap, GdkGC *gc, GdkFont *font,
+                        gint xx, gint y, DenemoObject *theobj);
+
 void
 drawbarline(GdkPixmap *pixmap, GdkGC *gc,gint xx, gint top_y,gint y, gint type);
