@@ -16,13 +16,14 @@
  */
 void
 draw_lyric (GdkPixmap * pixmap, GdkGC * gc, GdkFont * font,
-	    gint xx, gint y, mudelaobject * theobj)
+	    gint xx, gint y, DenemoObject * theobj)
 {
-	PangoContext *context = gdk_pango_context_get_for_screen (gdk_drawable_get_screen (pixmap));;
-	PangoLayout *layout =  pango_layout_new (context);
-	PangoFontDescription *desc =  pango_font_description_from_string (FONT);
-	
-	gchar *text = NULL;
+  PangoContext *context =
+    gdk_pango_context_get_for_screen (gdk_drawable_get_screen (pixmap));;
+  PangoLayout *layout = pango_layout_new (context);
+  PangoFontDescription *desc = pango_font_description_from_string (FONT);
+
+  gchar *text = NULL;
   gint length = 0;
   if (theobj->type == LYRIC)
     {
@@ -37,11 +38,11 @@ draw_lyric (GdkPixmap * pixmap, GdkGC * gc, GdkFont * font,
 #ifdef DEBUG
   g_print ("%s, %d\n", text, length);
 #endif
- 		
-		pango_layout_set_text (layout, text, -1);
-		pango_layout_set_font_description (layout, desc);
-		pango_font_description_free (desc);
-  
-		gdk_draw_layout(pixmap,gc, xx,y+STAFF_HEIGHT+10, layout);
+
+  pango_layout_set_text (layout, text, -1);
+  pango_layout_set_font_description (layout, desc);
+  pango_font_description_free (desc);
+
+  gdk_draw_layout (pixmap, gc, xx, y + STAFF_HEIGHT + 10, layout);
 
 }
