@@ -281,11 +281,11 @@ draw_chord (GdkPixmap * pixmap, GdkGC * gc, objnode * curobj, gint xx, gint y,
 
 
 
-  mudelaobject *prevmuditem =
-    (mudelaobject *) (curobj->prev ? curobj->prev->data : NULL);
-  mudelaobject *mudelaitem = (mudelaobject *) curobj->data;
-  mudelaobject *nextmuditem =
-    (mudelaobject *) (curobj->next ? curobj->next->data : NULL);
+  DenemoObject *prevmuditem =
+    (DenemoObject *) (curobj->prev ? curobj->prev->data : NULL);
+  DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
+  DenemoObject *nextmuditem =
+    (DenemoObject *) (curobj->next ? curobj->next->data : NULL);
   chord thechord = *(chord *) mudelaitem->object;
   gint duration = thechord.baseduration;
   gint noteheadtype = MIN (duration, 2);
@@ -316,15 +316,15 @@ draw_chord (GdkPixmap * pixmap, GdkGC * gc, objnode * curobj, gint xx, gint y,
     gc = gcs_bluegc ();
 
   if (mudelaitem->isinvisible)
-	  gc = gcs_yellowgc ();
+    gc = gcs_yellowgc ();
 
-  if (!thechord.tones)		/* We have a rest here */
+  if (!thechord.notes)		/* We have a rest here */
     draw_rest (pixmap, gc, duration, thechord.numdots, xx, y);
   else
     {
       /* Draw the noteheads and accidentals */
 
-      for (curnode = thechord.tones; curnode; curnode = curnode->next)
+      for (curnode = thechord.notes; curnode; curnode = curnode->next)
 	draw_notehead (pixmap, gc, (note *) curnode->data, duration,
 		       thechord.numdots, xx, y, accs, thechord.is_stemup);
 
@@ -511,7 +511,7 @@ draw_chord (GdkPixmap * pixmap, GdkGC * gc, objnode * curobj, gint xx, gint y,
 }
 
 
- 
+
 /**
  * Draw the articulations on the score
  *
@@ -528,7 +528,7 @@ draw_articulations (GdkPixmap * pixmap, GdkGC * gc,
   gint extra = 0;
   GList *tmp;
 
-  if (!options[25])
+  if (!options[0])
     {
       noteoptions[0] = bitmaphelper (NULL, feta26_scripts_trill);
       noteoptions[1] = bitmaphelper (NULL, feta26_scripts_turn);
@@ -670,62 +670,54 @@ draw_articulations (GdkPixmap * pixmap, GdkGC * gc,
 	drawbitmapinverse (pixmap, gc,
 			   options[24], xx, y + extra, ARPEGGIO_WIDTH,
 			   ARPEGGIO_HEIGHT);
-		
-	   if (*(enum ornament *) tmp->data == (enum ornament) UPPRALL)
-			drawbitmapinverse(pixmap, gc, options[23],
-									xx, y + extra, UPPRALL_WIDTH,
-									UPPRALL_HEIGHT);
-		
-		 if (*(enum ornament *) tmp->data == (enum ornament) FLAGEOLET)
-			drawbitmapinverse(pixmap, gc, options[11],
-									xx, y + extra, FLAGEOLET_SIZE,
-									FLAGEOLET_SIZE);
-		  if (*(enum ornament *) tmp->data == (enum ornament) OPEN)
-			drawbitmapinverse(pixmap, gc, options[12],
-									xx, y + extra, OPEN_WIDTH,
-									OPEN_HEIGHT);
-		   if (*(enum ornament *) tmp->data == (enum ornament)PRALLMORDENT)
-			drawbitmapinverse(pixmap, gc, options[13],
-									xx, y + extra, PRALLMORDENT_WIDTH,
-									PRALLMORDENT_HEIGHT);
-			 if (*(enum ornament *) tmp->data == (enum ornament) PRALLPRALL)
-			drawbitmapinverse(pixmap, gc, options[14],
-									xx, y + extra, PRALLPRALL_WIDTH,
-									PRALLPRALL_HEIGHT);
-			  if (*(enum ornament *) tmp->data == (enum ornament) PRALL)
-			drawbitmapinverse(pixmap, gc, options[15],
-									xx, y + extra, PRALL_WIDTH,
-									PRALL_HEIGHT);
-			   if (*(enum ornament *) tmp->data == (enum ornament) REVERSETURN)
-			drawbitmapinverse(pixmap, gc, options[16],
-									xx, y + extra, REVERSETURN_WIDTH,
-									REVERSETURN_HEIGHT);
-				 if (*(enum ornament *) tmp->data == (enum ornament)SEGNO)
-			drawbitmapinverse(pixmap, gc, options[17],
-									xx, y + extra, SEGNO_WIDTH,
-									SEGNO_HEIGHT);
-				  if (*(enum ornament *) tmp->data == (enum ornament) SFORZATO)
-			drawbitmapinverse(pixmap, gc, options[18],
-									xx, y + extra, SFORZATO_WIDTH,
-									SFORZATO_HEIGHT);
-				   if (*(enum ornament *) tmp->data == (enum ornament) STOPPED)
-			drawbitmapinverse(pixmap, gc, options[19],
-									xx, y + extra, STOPPED_SIZE,
-									STOPPED_SIZE);
-					 if (*(enum ornament *) tmp->data == (enum ornament) THUMB)
-			drawbitmapinverse(pixmap, gc, options[20],
-									xx, y + extra, THUMB_WIDTH,
-									THUMB_HEIGHT);
-					  if (*(enum ornament *) tmp->data == (enum ornament) TRILLELEMENT)
-			drawbitmapinverse(pixmap, gc, options[21],
-									xx, y + extra, TRILLELEMENT_WIDTH,
-									TRILLELEMENT_HEIGHT);
-					   if (*(enum ornament *) tmp->data == (enum ornament) TRILL_ELEMENT)
-			drawbitmapinverse(pixmap, gc, options[22],
-									xx, y + extra, TRILL_ELEMENT_WIDTH,
-									TRILL_ELEMENT_HEIGHT);
-			 
-    } //end for loop
+
+      if (*(enum ornament *) tmp->data == (enum ornament) UPPRALL)
+	drawbitmapinverse (pixmap, gc, options[23],
+			   xx, y + extra, UPPRALL_WIDTH, UPPRALL_HEIGHT);
+
+      if (*(enum ornament *) tmp->data == (enum ornament) FLAGEOLET)
+	drawbitmapinverse (pixmap, gc, options[11],
+			   xx, y + extra, FLAGEOLET_SIZE, FLAGEOLET_SIZE);
+      if (*(enum ornament *) tmp->data == (enum ornament) OPEN)
+	drawbitmapinverse (pixmap, gc, options[12],
+			   xx, y + extra, OPEN_WIDTH, OPEN_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) PRALLMORDENT)
+	drawbitmapinverse (pixmap, gc, options[13],
+			   xx, y + extra, PRALLMORDENT_WIDTH,
+			   PRALLMORDENT_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) PRALLPRALL)
+	drawbitmapinverse (pixmap, gc, options[14],
+			   xx, y + extra, PRALLPRALL_WIDTH,
+			   PRALLPRALL_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) PRALL)
+	drawbitmapinverse (pixmap, gc, options[15],
+			   xx, y + extra, PRALL_WIDTH, PRALL_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) REVERSETURN)
+	drawbitmapinverse (pixmap, gc, options[16],
+			   xx, y + extra, REVERSETURN_WIDTH,
+			   REVERSETURN_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) SEGNO)
+	drawbitmapinverse (pixmap, gc, options[17],
+			   xx, y + extra, SEGNO_WIDTH, SEGNO_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) SFORZATO)
+	drawbitmapinverse (pixmap, gc, options[18],
+			   xx, y + extra, SFORZATO_WIDTH, SFORZATO_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) STOPPED)
+	drawbitmapinverse (pixmap, gc, options[19],
+			   xx, y + extra, STOPPED_SIZE, STOPPED_SIZE);
+      if (*(enum ornament *) tmp->data == (enum ornament) THUMB)
+	drawbitmapinverse (pixmap, gc, options[20],
+			   xx, y + extra, THUMB_WIDTH, THUMB_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) TRILLELEMENT)
+	drawbitmapinverse (pixmap, gc, options[21],
+			   xx, y + extra, TRILLELEMENT_WIDTH,
+			   TRILLELEMENT_HEIGHT);
+      if (*(enum ornament *) tmp->data == (enum ornament) TRILL_ELEMENT)
+	drawbitmapinverse (pixmap, gc, options[22],
+			   xx, y + extra, TRILL_ELEMENT_WIDTH,
+			   TRILL_ELEMENT_HEIGHT);
+
+    }				//end for loop
 
 }
 
@@ -738,26 +730,28 @@ calc_offset (chord thechord, gint stemdir)
 {
   gint offset = 0;
   GList *tmp;
-  
-  for(tmp=thechord.ornamentlist; tmp; tmp=tmp->next) 
-  {
-  if (*(enum ornament *) tmp->data == (enum ornament) FERMATA || 
-	   *(enum ornament *) tmp->data == (enum ornament) TURN ||
-      *(enum ornament *) tmp->data == (enum ornament) TRILL || 
-	   *(enum ornament *) tmp->data == (enum ornament) MORDENT)
-    offset = -LINE_SPACE - 7;
-  else if (*(enum ornament *) tmp->data == (enum ornament) STACCATO || 
-	        *(enum ornament *) tmp->data == (enum ornament) TENUTO && stemdir)
-    offset = thechord.lowesty + 10;
-  else if (*(enum ornament *) tmp->data == (enum ornament) STACCATO || 
-	        *(enum ornament *) tmp->data == (enum ornament) TENUTO)
-    offset = thechord.highesty - 10;
-  else if (*(enum ornament *) tmp->data == (enum ornament) D_ACCENT && stemdir)
-    offset = thechord.lowesty + 10;
-  else if (*(enum ornament *) tmp->data == (enum ornament) MARCATO || 
-	        *(enum ornament *) tmp->data == (enum ornament) D_ACCENT)
-    offset = -thechord.highesty - 6;
-  }
+
+  for (tmp = thechord.ornamentlist; tmp; tmp = tmp->next)
+    {
+      if (*(enum ornament *) tmp->data == (enum ornament) FERMATA ||
+	  *(enum ornament *) tmp->data == (enum ornament) TURN ||
+	  *(enum ornament *) tmp->data == (enum ornament) TRILL ||
+	  *(enum ornament *) tmp->data == (enum ornament) MORDENT)
+	offset = -LINE_SPACE - 7;
+      else if (*(enum ornament *) tmp->data == (enum ornament) STACCATO ||
+	       *(enum ornament *) tmp->data == (enum ornament) TENUTO
+	       && stemdir)
+	offset = thechord.lowesty + 10;
+      else if (*(enum ornament *) tmp->data == (enum ornament) STACCATO ||
+	       *(enum ornament *) tmp->data == (enum ornament) TENUTO)
+	offset = thechord.highesty - 10;
+      else if (*(enum ornament *) tmp->data == (enum ornament) D_ACCENT
+	       && stemdir)
+	offset = thechord.lowesty + 10;
+      else if (*(enum ornament *) tmp->data == (enum ornament) MARCATO ||
+	       *(enum ornament *) tmp->data == (enum ornament) D_ACCENT)
+	offset = -thechord.highesty - 6;
+    }
 
   return offset;
 }
