@@ -8,11 +8,10 @@
 
 
 void
-insert_dynamic (gpointer callback_data, guint callback_action,
-		GtkWidget *widget);
+insert_dynamic (GtkAction *action ,gpointer callback_data);
 
 void
 insertdynamic (GtkWidget *widget, gpointer data);
 
-void add_dynamic(mudelaobject *mudelaobj, GString *dynamic);
+void add_dynamic(DenemoObject *mudelaobj, GString *dynamic);
   
