@@ -5,7 +5,14 @@
  * (c) 2001 Eric Galluzzo
  */
 
-#include <gtk/gtk.h>
 
-void exportabc (gchar * thefilename, struct scoreinfo *si, gint start,
+#ifndef EXPORTABC_H
+#define EXPORTABC_H
+
+#include <denemo/denemo.h>
+
+void exportabc (gchar * thefilename, DenemoScore *si, gint start,
 		gint end);
+
+
+#endif
