@@ -12,9 +12,8 @@
 void 
 insertfigure(GtkWidget *widget, gpointer data);
 void 
-figure_insert(GtkAction *action, scoreinfo *si);
-mudelaobject *
+figure_insert(GtkAction *action, DenemoGUI *gui);
+DenemoObject *
 newfigure (gint baseduration, gint numdots, gchar *figs);
 
 #endif
-  
