@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +17,21 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -45,7 +55,7 @@
      CLEFTYPE = 271,
      ORNAMENT = 272,
      FULL = 273,
-     PARTIAL = 274,
+     PARTIAL_ = 274,
      MODE = 275,
      BARTYPE = 276,
      TEMPOTERM = 277,
@@ -66,6 +76,7 @@
      HAIRPINTYPE = 292
    };
 #endif
+/* Tokens.  */
 #define STAFFNAME 258
 #define TIE 259
 #define END 260
@@ -82,7 +93,7 @@
 #define CLEFTYPE 271
 #define ORNAMENT 272
 #define FULL 273
-#define PARTIAL 274
+#define PARTIAL_ 274
 #define MODE 275
 #define BARTYPE 276
 #define TEMPOTERM 277
@@ -105,9 +116,10 @@
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
 #line 61 "./frogparser.y"
-typedef union YYSTYPE {
+{
   gfloat f;
   char string[FROG_MAX_TOKEN_STRING];
   int number;
@@ -126,9 +138,10 @@ typedef union YYSTYPE {
   struct p_tupops t_tupops;
   struct p_slur t_slur;
   struct p_hairpin t_hairpin;
-} YYSTYPE;
-/* Line 1285 of yacc.c.  */
-#line 132 "frogparser.tab.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 144 "frogparser.tab.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -136,5 +149,3 @@ typedef union YYSTYPE {
 
 extern YYSTYPE froglval;
 
-
-
