@@ -15,12 +15,12 @@
  * Create a new grace start object
  *
  */
-mudelaobject *
+DenemoObject *
 newgracestart ()
 {
-  mudelaobject *thegrace;
+  DenemoObject *thegrace;
   grace *newgrace = (grace *) g_malloc (sizeof (grace));
-  thegrace = (mudelaobject *) g_malloc (sizeof (mudelaobject));
+  thegrace = (DenemoObject *) g_malloc (sizeof (DenemoObject));
 
   thegrace->type = GRACE_START;
   newgrace->on_beat = FALSE;
@@ -35,12 +35,12 @@ newgracestart ()
  * Create a new grace end object
  *
  */
-mudelaobject *
+DenemoObject *
 newgraceend ()
 {
-  mudelaobject *thegrace;
+  DenemoObject *thegrace;
 
-  thegrace = (mudelaobject *) g_malloc (sizeof (mudelaobject));
+  thegrace = (DenemoObject *) g_malloc (sizeof (DenemoObject));
 
   thegrace->type = GRACE_END;
 
