@@ -4,8 +4,14 @@
    For Denemo, the GNU graphical music notation package
    (c) 2000-2005 Olivier Vermersch, Matthew Hiller */
 
-void
-configure_keyboard_dialog (GtkAction *action ,struct scoreinfo *si);
+#ifndef KBDINTERFACE_H
+#define KBDINTERFACE_H
 
 void
-configure_keyboard_dialog_OLD (GtkAction *action, struct scoreinfo *si);
+configure_keyboard_dialog (GtkAction *action ,DenemoGUI *gui);
+
+void
+configure_keyboard_dialog_OLD (GtkAction *action, DenemoGUI *gui);
+
+
+#endif
