@@ -1,7 +1,7 @@
 /* lilydirectives.h
  *
  *
- * (c) 2000, 2001 Adam Tee <eenajt@electeng.leeds.ac.uk>
+ * (c) 2000-2005 Adam Tee <eenajt@electeng.leeds.ac.uk>
  *
  */
 
@@ -12,7 +12,7 @@
 #include <denemo/denemo.h>
 
 void insertdirective(GtkWidget *widget, gpointer data);
-void lily_directive(gpointer callback_data, guint callback_action, GtkWidget *widget);
+void lily_directive(GtkAction *action, gpointer callback_data);
 
 
 #endif
