@@ -4,7 +4,7 @@
 
 /* For Denemo, a gtk+ frontend to GNU Lilypond
  * (c) 2000-2005 Matthew Hiller */
-/*#define DEBUG 1*/
+//#define DEBUG 1
 #include "chordops.h"
 #include <denemo/denemo.h>
 #include "lyparserfuncs.h"
@@ -17,97 +17,134 @@
 #include "staffops.h"
 #include "calculatepositions.h"
 #include "measureops.h"
-#include "exportmudela.h"
+#include "exportlilypond.h"
 #include "commandfuncs.h"
 #include "articulations.h"
 
+ crescendo_state cresc_state;
+
 gboolean g_string_equal (const GString * v, const GString * v2);
 
 /* RECURSIVE return the first object in object list 
    CUROBJ of type thetype before any CHORD type,
    following branches made for references to identifiers 
 */
-static mudelaobject *
+static DenemoObject *
 first_node_context (objnode * curobj, gint thetype)
 {
   while (curobj)
     {
-      if (((mudelaobject *) curobj->data)->type == MUSIC_IDENTIFIER)
+      if (((DenemoObject *) curobj->data)->type == MUSIC_IDENTIFIER)
 	{
-	  mudelaobject *mud = first_node_context (br (curobj), thetype);
+	  DenemoObject *mud = first_node_context (br (curobj), thetype);
 	  if (mud)
 	    return mud;
 	}
-      if (((mudelaobject *) curobj->data)->type == thetype)
-	return (mudelaobject *) curobj->data;
-      if (((mudelaobject *) curobj->data)->type == CHORD)
+      if (((DenemoObject *) curobj->data)->type == thetype)
+	return (DenemoObject *) curobj->data;
+      if (((DenemoObject *) curobj->data)->type == CHORD)
 	return NULL;
       curobj = curobj->next;
     }
   return NULL;
 }
 
+/* delete obj from curmeasure if it occurs before the first chord */
+static void
+delete_context(measurenode * curmeasure, DenemoObject * obj)
+{
+  objnode *curobj = (objnode *) curmeasure->data;
+ while (curobj)
+    {
+      if ((DenemoObject *) curobj->data == obj)
+      {
+        curmeasure->data = g_list_remove_link ((objnode *) curmeasure->data,
+                                          curobj);
+	freeobject ((DenemoObject *) curobj->data);
+        g_list_free_1 (curobj);
+        return;
+      }
+      if (((DenemoObject *) curobj->data)->type == CHORD)
+        return ;
+      curobj = curobj->next;
+    }
+}
 /* return the first object in measure curmeasure of type thetype before any CHORD type */
-static mudelaobject *
+static DenemoObject *
 first_context (measurenode * curmeasure, gint thetype)
 {
   objnode *curobj = (objnode *) curmeasure->data;
   return first_node_context (curobj, thetype);
 }
 
+/* Denemo holds initial staff properties in the staff structure rather
+   than nodes, so transfer node data to staff structure and delete
+   the nodes. If we do not do this, objects like initial key, clef, and time
+   signatures are shown twice in denemo */
 static void
-set_initial_staffcontext (staff * curstaffstruct, struct scoreinfo *si)
+set_initial_staffcontext (DenemoStaff * curstaffstruct, DenemoScore *si)
 {
   measurenode *firstmeasure = curstaffstruct->measures;
-  mudelaobject *obj;
+  DenemoObject *obj;
+  curstaffstruct->context = DENEMO_NONE;
   g_assert (firstmeasure);
-  if ((obj = first_context (firstmeasure, CLEF))
-      || (obj = first_context (firstmeasure, INITIAL_CLEF)))
+  if ((obj = first_context (firstmeasure, CLEF)))
     {
-      /* DENEMO treats CLEF as clef change, so make the initial clef
-         a different type */
-      obj->type = (enum objtype) INITIAL_CLEF;
-      setpixelmin (obj);	/* different object different width */
       curstaffstruct->sclef = ((clef *) obj->object)->type;
       find_leftmost_staffcontext (curstaffstruct, si);
       fixnoteheights (curstaffstruct);
-      /*  find_xes_in_all_measures (si); core dumps */
+      delete_context (firstmeasure, obj);
     }
-  if ((obj = first_context (firstmeasure, KEYSIG))
-      || (obj = first_context (firstmeasure, INITIAL_KEYSIG)))
+  if ((obj = first_context (firstmeasure, KEYSIG)))
     {
-      obj->type = (enum objtype) INITIAL_KEYSIG;
-      setpixelmin (obj);
       curstaffstruct->skey = ((keysig *) obj->object)->number;
-      initkeyaccs (curstaffstruct->skeyaccs, curstaffstruct->skey);
+      dnm_setinitialkeysig (curstaffstruct, curstaffstruct->skey, curstaffstruct->skey_isminor);
+      //initkeyaccs (curstaffstruct->skeyaccs, curstaffstruct->skey);
+      delete_context (firstmeasure, obj);
     }
-  if ((obj = first_context (firstmeasure, TIMESIG))
-      || (obj = first_context (firstmeasure, INITIAL_TIMESIG)))
+  if ((obj = first_context (firstmeasure, TIMESIG)))
     {
-      obj->type = (enum objtype) INITIAL_TIMESIG;
-      setpixelmin (obj);
       curstaffstruct->stime1 = ((timesig *) obj->object)->time1;
       curstaffstruct->stime2 = ((timesig *) obj->object)->time2;
+      delete_context (firstmeasure, obj);
     }
+  if ((obj = first_context (firstmeasure, SET )))
+  {
+	char *pt  = strstr(obj->user_string, "Staff.midiInstrument");
+	if ( pt != NULL)
+	{
+	    char tmp[40];
+	    int i;
+
+	    pt += 20;
+	    while(*pt && *pt != '"')pt++;
+	    if (*pt) pt++;
+	    for(i=0; *pt && *pt != '"' && i < 39; i++)
+		tmp[i] = *pt++;
+	    tmp[i] = 0;
+	    curstaffstruct->midi_instrument = g_string_new(tmp);
+	    delete_context (firstmeasure, obj);
+	}
+  }
 }
 
 void
-set_initial_staffcontexts (struct scoreinfo *si)
+set_initial_staffcontexts (DenemoScore *si)
 {
   staffnode *curstaff = si->thescore;
 
   si->maxkeywidth = G_MININT;
   for (; curstaff; curstaff = curstaff->next)
     {
-      set_initial_staffcontext ((staff *) curstaff->data, si);
+      set_initial_staffcontext ((DenemoStaff *) curstaff->data, si);
     }
 }
 
 
 void
-setstaffname (struct scoreinfo *si, gchar * str)
+setstaffname (DenemoScore * si, gchar * str)
 {
-  staff *curstaffstruct = (staff *) si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
   g_string_assign (curstaffstruct->lily_name, str);
   set_denemo_name (curstaffstruct->lily_name, curstaffstruct->denemo_name);
@@ -136,15 +173,15 @@ cleftypefromname (gchar * str)
 }
 
 void
-set_clef (struct scoreinfo *si, gchar * str)
+set_clef (DenemoScore * si, gchar * str)
 {
-  ((staff *) si->currentstaff->data)->sclef = cleftypefromname (str);
+  ((DenemoStaff *) si->currentstaff->data)->sclef = cleftypefromname (str);
 }
 
 void
-set_key (struct scoreinfo *si, struct twoints t)
+set_key (DenemoScore * si, struct twoints t)
 {
-  staff *curstaffstruct = (staff *) si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
   if (t.b)
     {				/* Minor key  */
@@ -156,13 +193,14 @@ set_key (struct scoreinfo *si, struct twoints t)
       curstaffstruct->skey = t.a;
       curstaffstruct->skey_isminor = FALSE;
     }
-  initkeyaccs (curstaffstruct->skeyaccs, curstaffstruct->skey);
+   dnm_setinitialkeysig (curstaffstruct, curstaffstruct->skey, curstaffstruct->skey_isminor);
+  //initkeyaccs (curstaffstruct->skeyaccs, curstaffstruct->skey);
 }
 
 void
-set_time (struct scoreinfo *si, struct twoints t)
+set_time (DenemoScore * si, struct twoints t)
 {
-  staff *curstaffstruct = (staff *) si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 
   curstaffstruct->stime1 = t.a;
   curstaffstruct->stime2 = t.b;
@@ -245,7 +283,7 @@ pitchtomid_c_offset (gchar name, gint octave)
 }
 
 void
-addtonewrapper (mudelaobject * curmudelaobj, gchar tonetype,
+addtonewrapper (DenemoObject * curmudelaobj, gchar tonetype,
 		gint enshift, gint octave, struct twoints duration,
 		gint dclef)
 {
@@ -259,44 +297,9 @@ addtonewrapper (mudelaobject * curmudelaobj, gchar tonetype,
 }
 
 void
-set_tone_option (mudelaobject * curmudelaobj, gchar * option)
+set_tone_option (DenemoObject * curmudelaobj, gchar * option)
 {
-
-  if (!strcmp (option, "fermata"))
-    ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(FERMATA,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-  else if (!strcmp (option, "trill"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(TRILL,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-    
-  else if (!strcmp (option, "turn"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(TURN,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-    
-  else if (!strcmp (option, "mordent"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(MORDENT,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-  else if (!strcmp (option, "accent"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(D_ACCENT,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);    
-  else if (!strcmp (option, "staccato"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(STACCATO,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-  else if (!strcmp (option, "staccatissimo"))
-    ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(STACCATISSIMO,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-  else if (!strcmp (option, "tenuto"))
-	  ((chord *)curmudelaobj->object)->ornamentlist = 
-				  insert_ornament_list(TENUTO,
-					  					    ((chord *)curmudelaobj->object)->ornamentlist);
-    
+  set_articulation (option, curmudelaobj);
 }
 
 typedef struct Keyword_ent
@@ -318,6 +321,7 @@ static Keyword_ent the_key_tab[] = {
   {"alternative", ALTERNATIVE},
   {"bar", BAR},
   {"breathe", BREATHE},
+  {"break", BREAK},
   {"char", CHAR_T},
   {"chordmodifiers", CHORDMODIFIERS},
   {"chords", CHORDS},
@@ -336,12 +340,16 @@ static Keyword_ent the_key_tab[] = {
   {"glissando", GLISSANDO},
   {"header", HEADER},
   {"in", IN_T},
-  {"lyrics", LYRICS},
   {"key", KEY},
   {"mark", MARK},
+  {"new", NEWCONTEXT},
   {"pitch", PITCH},
   {"time", TIME_T},
   {"times", TIMES},
+  {"layout", LAYOUT},
+  {"lyricmode", LYRICMODE},
+  {"lyrics", LYRICS},
+  {"lyricsto", LYRICSTO},
   {"midi", MIDI},
   {"mm", MM_T},
   {"name", NAME},
@@ -352,7 +360,7 @@ static Keyword_ent the_key_tab[] = {
   {"set", SET},
   {"rest", REST},
   {"revert", REVERT},
-  {"partial", PARTIAL},
+  {"partial", PARTIAL_},
   {"paper", PAPER},
   {"penalty", PENALTY},
   {"property", PROPERTY},
@@ -371,10 +379,18 @@ static Keyword_ent the_key_tab[] = {
   {"transpose", TRANSPOSE},
   {"type", TYPE},
   {"unset", UNSET},
-  {"layout", LAYOUT},
+  { "version", LILYVERSION},
   {0, 0}
 };
 
+static Keyword_ent the_par_tab[] = {
+  {"MUSIC_IDENTIFIER", MUSIC_IDENTIFIER},
+  {"voicecontext", voicecontext},
+  {"staffcontext", staffcontext},
+  {"endcontext", endcontext},
+  { NULL, 0}
+};
+
 gint
 lookup_keyword (gchar * str)
 {
@@ -389,6 +405,23 @@ lookup_keyword (gchar * str)
 
   return -1;
 }
+gchar *
+lookup_type (gint type)
+{
+  int i;
+  for (i = 0; the_key_tab[i].str; i++)
+    {
+      if (the_key_tab[i].type == type)
+	return the_key_tab[i].str;	/*very inefficient! */
+    }
+  for (i = 0; the_par_tab[i].str; i++)
+    {
+      if (the_par_tab[i].type == type)
+	return the_par_tab[i].str;	/*very inefficient! */
+    }
+
+  return "Unknown";
+}
 
 
 
@@ -397,40 +430,62 @@ lookup_keyword (gchar * str)
  * sets si->currentstaffnum to correspond 
  */
 static void
-findstaff (GString * name, scoreinfo * si)
+findstaff (GString * name, DenemoScore * si)
 {
-  staff *curstaffstruct;
+  DenemoStaff *curstaffstruct;
   if (si->thescore)
+  {
     for (si->currentstaff = si->thescore, si->currentstaffnum = 0;
 	 si->currentstaff;
 	 si->currentstaff = si->currentstaff->next, si->currentstaffnum++)
       {
-	curstaffstruct = (staff *) (si->currentstaff->data);
+	curstaffstruct = (DenemoStaff *) (si->currentstaff->data);
 	if (g_string_equal (curstaffstruct->staff_name, name))
+	{
 	  return;
+	}
       }
+  }
   si->currentstaff = NULL;
   si->currentstaffnum = g_list_length (si->thescore);	/*set to insert at end */
 }
 
+static GList *staffctx = NULL, *voicectx = NULL, *lyricsctx =
+  NULL, *figuresctx = NULL;
+
+static void
+anewstaff (DenemoScore * si, GString * staffname, GString * voicename);
 /* set si->currentstaff to the insertion point for voice named NAME in staff 
  * STAFFCTX, return TRUE if voice already exists else FALSE. 
  * sets si->currentstaffnum to correspond 
  */
 static gboolean
-findvoice (GString * name, GList * staffctx, scoreinfo * si)
+findvoice (GString *name, DenemoScore * si)
 {
-  staff *curstaffstruct;
-  staff *staffctxstruct;
+  DenemoStaff *curstaffstruct;
+  DenemoStaff *staffctxstruct;
+  if (!si->thescore || !staffctx)
+  {
+  	si->currentstaff = NULL;
+  	si->currentstaffnum = g_list_length (si->thescore);	/*set to insert at end */
+      	si->currentstaff = si->thescore;
+      	anewstaff (si, g_string_new ("staff"), name);
+	si->currentmeasurenum = 1;
+      	staffctx = si->currentstaff = g_list_last (si->thescore);
+	set_denemo_name (name, staffstruct (staffctx)->denemo_name);
+  }
   if (si->thescore)
+  {
     if (staffctx)
-      {
-	staffctxstruct = (staff *) (staffctx->data);
+    {
+	staffctxstruct = (DenemoStaff *) (staffctx->data);
 	for (si->currentstaff = si->thescore, si->currentstaffnum = 1;
 	     si->currentstaff && (staffctx != si->currentstaff);
 	     si->currentstaff = si->currentstaff->next, si->currentstaffnum++)
 	  /* move to primary voice in current staff */ ;
-	curstaffstruct = (staff *) (si->currentstaff->data);
+    
+
+	curstaffstruct = (DenemoStaff *) (si->currentstaff->data);
 	if (curstaffstruct->lily_name->len == 0)
 	  {			/* no voice here yet */
 	    curstaffstruct->lily_name = name;
@@ -450,17 +505,17 @@ findvoice (GString * name, GList * staffctx, scoreinfo * si)
 	si->currentstaff = si->currentstaff->prev, si->currentstaffnum--;
 	/* just come off this staff, go back one */
 	return FALSE;
-      }
-  /* FIXME these cases - no staffs or no staff context */
+     }
+  }
   si->currentstaff = NULL;
   si->currentstaffnum = 0;
   return FALSE;
 }
 
 static void
-anewstaff (scoreinfo * si, GString * staffname, GString * voicename)
+anewstaff (DenemoScore * si, GString * staffname, GString * voicename)
 {
-  staff *thestaffstruct = (staff *) g_malloc0 (sizeof (staff));
+  DenemoStaff *thestaffstruct = (DenemoStaff *) g_malloc0 (sizeof (DenemoStaff));
 
   thestaffstruct->sclef = DENEMO_TREBLE_CLEF;
   thestaffstruct->stime1 = 4;
@@ -470,6 +525,8 @@ anewstaff (scoreinfo * si, GString * staffname, GString * voicename)
   thestaffstruct->denemo_name = g_string_new ("");
   thestaffstruct->lily_name = voicename;
   thestaffstruct->midi_instrument = g_string_new ("acoustic grand");
+  thestaffstruct->voicenumber = 1;
+  thestaffstruct->nummeasures = 1;
   if (si->thescore)
     {
       si->thescore =
@@ -495,10 +552,10 @@ findtok (GList * g, int t)
   return g;
 }
 
-/* put separate chords into a tones list of a chord and return that,
+/* put separate chords into a notes list of a chord and return that,
  * amalgamating the user_strings 
  */
-static mudelaobject *
+static DenemoObject *
 generate_chord (GList * chordnode)
 {
   GList *g;
@@ -508,7 +565,7 @@ generate_chord (GList * chordnode)
   if (firstchord == NULL)
     {
       g_warning ("<> without any notes");
-      return (mudelaobject *) chordnode->data;	/* FIXME return everything */
+      return (DenemoObject *) chordnode->data;	/* FIXME return everything */
     }
 
   for (str = NULL, g = chordnode; g; g = g->next)
@@ -523,31 +580,31 @@ generate_chord (GList * chordnode)
     {
       if (ntype (g) == CHORD)
 	{
-	  addtone ((mudelaobject *) firstchord->data,
+	  addtone ((DenemoObject *) firstchord->data,
 		   ((note
-		     *) (((chord *) (((mudelaobject *) g->data)->object))->
-			 tones->data))->mid_c_offset,
+		     *) (((chord *) (((DenemoObject *) g->data)->object))->
+			 notes->data))->mid_c_offset,
 		   ((note
-		     *) (((chord *) (((mudelaobject *) g->data)->object))->
-			 tones->data))->enshift, 0);
+		     *) (((chord *) (((DenemoObject *) g->data)->object))->
+			 notes->data))->enshift, 0);
 	}			/* FIXME memory leak */
     }
-  return (mudelaobject *) firstchord->data;
+  return (DenemoObject *) firstchord->data;
 }
 
 /* RECURSIVE: generate_chords_and_sequentials()
  * called within a SEQUENTIAL it detects <> and { } music.
  * The <> are chords are in lilypond style ie SIMULTANEOUS nodes 
- * this function turns them into tones lists
+ * this function turns them into notes lists
  * belonging to a chord structure in denemo style
  * the { } are things like repeats etc, inline these
  * Note we don't cope with new contexts being created...
  */
 
-static int create_score (scoreinfo * si, GList * top);
+static int create_score (DenemoScore * si, GList * top);
 
 static void
-generate_chords_and_sequentials (scoreinfo * si, GList * g)
+generate_chords_and_sequentials (DenemoScore * si, GList * g)
 {
   GList *chordnode;
 
@@ -566,16 +623,17 @@ generate_chords_and_sequentials (scoreinfo * si, GList * g)
 	{
 	  /*create a text node for the u_str, one for the u_post_str and 
 	     in between link in the create_score(br(chordnode) */
+	  GList *ret;
 	  GList *temp = br (chordnode);
 	  generate_chords_and_sequentials (si, chordnode);
 	  u_str (temp) = g_strconcat (u_str (chordnode), u_str (temp), NULL);
 	  (chordnode->prev)->next = NULL;
-	  g_list_concat (chordnode->prev, temp);
+	  ret = g_list_concat (chordnode->prev, temp);
 	  temp = g_list_last (temp);
 	  u_str (temp) =
 	    g_strconcat (u_str (temp), u_post_str (chordnode), NULL);
 	  chordnode->prev = NULL;
-	  g_list_concat (temp, chordnode->next);
+	  ret = g_list_concat (temp, chordnode->next);
 	  /* FIXME memory leak of chordnode itself */
 	}
     }
@@ -592,14 +650,14 @@ recursive_end_of_first_measure (GList * theobjs, gint * ptime1, gint * ptime2,
 {
 
   objnode *curobjnode;
-  mudelaobject *theobj;
+  DenemoObject *theobj;
   gint basic_ticks_in_tuplet_group = 0;
   gint basic_ticks_in_grace_group = 0;
   gboolean in_tuplet = FALSE;
   gboolean in_grace = FALSE;
   for (curobjnode = theobjs; curobjnode; curobjnode = curobjnode->next)
     {
-      theobj = (mudelaobject *) curobjnode->data;
+      theobj = (DenemoObject *) curobjnode->data;
       theobj->starttick =
 	*pticks_so_far + (basic_ticks_in_tuplet_group * *pnumerator
 			  / *pdenominator) + basic_ticks_in_grace_group;
@@ -660,7 +718,6 @@ recursive_end_of_first_measure (GList * theobjs, gint * ptime1, gint * ptime2,
 	  /*      *pticks_so_far += basic_ticks_in_grace_group; */
 	  basic_ticks_in_grace_group = 0;
 	  break;
-	case INITIAL_TIMESIG:
 	case TIMESIG:
 	  *ptime1 = ((timesig *) theobj->object)->time1;
 	  *ptime2 = ((timesig *) theobj->object)->time2;
@@ -681,6 +738,15 @@ recursive_end_of_first_measure (GList * theobjs, gint * ptime1, gint * ptime2,
 	      }
 	  }
 	  break;
+
+	case SKIPNAME:  // FIXME memory leak and
+			// This assumes skip is for entire bar which is not
+			// generally true. The issue is duration, dot(s) used
+			// by denemo cannot describe full measure skip 
+			// durations in some time signatures such as 5/4. 
+	  return curobjnode;
+	  break;
+
 	default:
 	  break;
 	}
@@ -691,6 +757,7 @@ recursive_end_of_first_measure (GList * theobjs, gint * ptime1, gint * ptime2,
       if (*pticks_so_far >= *ptickspermeasure)
 	break;
     }
+
   return curobjnode;
 }
 
@@ -718,11 +785,13 @@ end_of_first_measure (GList * theobjs, gint * ptime1, gint * ptime2)
 /*  attach the measures in BRANCH to the MEASURES_LIST, by counting ticks 
  * return the measures list built up */
 static GList *
-break_into_measures (GList * branch, GList * measures_list)
+break_into_measures (GList * branch, DenemoStaff * staff)
 {
+  GList * measures_list = staff->measures;
   GList *barline;
   GList *rest;
-  gint time1 = 4, time2 = 4;	/*default timesig */
+  gint time1 = staff->stime1; 
+  gint time2 = staff->stime2;
   barline = end_of_first_measure (branch, &time1, &time2);
   if (barline)
     {
@@ -734,12 +803,13 @@ break_into_measures (GList * branch, GList * measures_list)
   else
     rest = NULL;
   measures_list = g_list_append (measures_list, branch);
-  while (rest)
+  while (rest && ntype(rest) != BAR)
     {
       barline = end_of_first_measure (rest, &time1, &time2);
       if (barline)
 	{
 	  measures_list = g_list_append (measures_list, rest);
+	  staff->nummeasures++;
 	  rest = barline->next;
 	  if (rest)
 	    rest->prev = NULL;
@@ -748,6 +818,7 @@ break_into_measures (GList * branch, GList * measures_list)
       else
 	{
 	  measures_list = g_list_append (measures_list, rest);
+	  staff->nummeasures++;
 	  rest = NULL;
 
 	}
@@ -755,26 +826,161 @@ break_into_measures (GList * branch, GList * measures_list)
   return measures_list;
 }
 
-static GList *staffctx = NULL, *voicectx = NULL, *lyricsctx =
-  NULL, *figuresctx = NULL;
+/*
+	is_tied is TRUE after either a slur or tie becomes active
+	calling is_tied with an argument of NULL resets it's state
+*/
+static gboolean
+is_tied ( chord * chord_pt)
+{
+    static gboolean active_tie;
+    static gboolean active_slur;
+    gboolean ret = active_tie || active_slur;
+
+    if (chord_pt == NULL)
+      {
+	active_tie = FALSE;
+	active_slur = FALSE;
+	return FALSE;
+      }
+
+    if (chord_pt->is_tied)
+	active_tie = TRUE;
+    else
+	active_tie = FALSE;
+
+    if (chord_pt->slur_end_p)
+	active_slur = FALSE;
+
+    if (chord_pt->slur_begin_p)
+	active_slur = TRUE;
+
+    return ret;
+}
+/*
+	recursively scan lyrucsto object lyparser tree for lyrics
+	and attach lyrics to chord structure
+
+	Note: Denemo does not support multiple lines of lyrics.
+*/ 
+static gboolean
+get_lyric (GList * glyric, measurenode **meas, objnode *curobjnode)
+{
+      DenemoObject *curobj;
+
+      if (glyric == NULL)
+	  return (FALSE);
+
+      switch (ntype (glyric))
+      {
+	case MUSIC_IDENTIFIER:
+	  get_lyric (((nodeid*)(glyric)->data)->id, meas, curobjnode);
+	  glyric = glyric->next;
+	  break;
+
+	case SIMULTANEOUS:
+	  get_lyric (br (glyric), meas, curobjnode);
+	  if ((br (glyric))->next)
+		g_warning("Lyricsto: Denemo does not support more than one line of lyrics");
+	  glyric = glyric->next;
+	  break;
+
+	case SEQUENTIAL:
+	  get_lyric (br (glyric), meas, curobjnode);
+	  glyric = glyric->next;
+	  break;
+
+	case OVERRIDE:
+	case LYRICMODE:
+	case lyricscontext:
+	case endcontext:
+	  glyric = glyric->next;
+	  break;
+
+	case LYRICS:
+	case SKIP:
+	  do
+	    {
+		if (curobjnode == NULL)
+		  {
+		    if (*meas == NULL)
+			return FALSE;
+		    curobjnode = (objnode *) (*meas)->data;
+		    *meas = (*meas)->next;
+		  }
+                curobj = (DenemoObject *) curobjnode->data;
+	        if (curobj->type == CHORD 
+		    && ( (chord *) curobj->object)->numnotes
+		    && ! is_tied ((chord *) curobj->object))
+	          {
+		    if (ntype (glyric) == LYRICS)
+	  	        ( (chord *) curobj->object)->lyric = 
+				((chord *) gobj (glyric))->lyric;
+	  	    glyric = glyric->next;
+		  }
+		curobjnode = curobjnode->next;
+	    }
+	  while (glyric && (ntype (glyric) == LYRICS || ntype (glyric) == SKIP));
+	  break;
+
+	default:
+	  g_warning("get_lyric unexpected lyric type %d", ntype (glyric));
+	  return FALSE;
+	  break;
+
+      }
+      return (get_lyric (glyric, meas, curobjnode));
+
+}
+/*
+	process the lyricsto list generated by the lyparser
+*/
+static void
+process_lyricsto (DenemoScore * si, GList * top)
+{
+	staffnode *staff;
+        measurenode *meas;
+
+
+    for (staff = si->thescore; staff; staff = staff->next)
+      {
+	if (!strcmp (( (DenemoStaff *) (staff->data))->lily_name->str, 
+		u_str (top)))
+	{
+	  break;
+	}
+      }
+      if (!staff)
+      {
+	g_warning("Lyricsto staff %s not found\n", u_str (top));
+	return;
+      }
+
+
+      meas = (measurenode *) (((DenemoStaff *) (staff->data))->measures);
+      get_lyric (br (top), &meas, NULL);
+}
 
 /* create_score: Recursively traverse the GList TOP which represents a 
    score block of the input lily file. Create denemo structures to enable 
    it to be edited graphically
 */
 static int
-create_score (scoreinfo * si, GList * top)
+create_score (DenemoScore * si, GList * top)
 {
   GList *g;
 
-  staff *curstaffstruct;
+  DenemoStaff *curstaffstruct;
 #if DEBUG
+
+  char *name;
   g_print
     ("The parse tree from this node downwards looks"
      " like this\n*************************************\n");
   for (g = top; g; g = g->next)
     {
-      g_print ("node type = %d string = %s\n",
+      g_print ("node type = %s(%d) string = %s\n",
+	       lookup_type(((nodegeneric *) g->data)->type),
 	       ((nodegeneric *) g->data)->type,
 	       ((nodegeneric *) g->data)->user_string);
     }
@@ -784,26 +990,24 @@ create_score (scoreinfo * si, GList * top)
   for (g = top; g; (g = g->next))
     {
 #if DEBUG
-      g_print ("Handling: node type = %d string = %s\n",
+      g_print ("Handling: node type = %d string = %s\t",
 	       ((nodegeneric *) g->data)->type,
 	       ((nodegeneric *) g->data)->user_string);
 #endif
       switch (ntype (g))
 	{
-	case NOTES:
-#if DEBUG
-	  g_print ("Found notes\n");
-#endif
-	  break;
 	case figuredbasscontext:
 	case staffcontext:
-	  findstaff (gstr (g), si);	/*sets si->currentstaffnum */
+	  ; // for GString 
+	  GString *staffname = gstr (g) ? gstr (g) : g_string_new ("");
+	  findstaff (staffname, si);	/*sets si->currentstaffnum */
 	  staffctx = si->currentstaff;
 	  if (!staffctx)
 	    {
 	      si->currentstaff = si->thescore;
-	      anewstaff (si, gstr (g), g_string_new (""));
+	      anewstaff (si, staffname, g_string_new (""));
 	      staffctx = si->currentstaff = g_list_last (si->thescore);
+	      set_denemo_name (staffname, staffstruct (staffctx)->denemo_name);
 	      staffstruct (staffctx)->voicenumber = 1;
 	    }
 	  si->currentprimarystaff = staffctx;
@@ -817,21 +1021,26 @@ create_score (scoreinfo * si, GList * top)
 				0);
 		  return -1;
 		}
-	      staffs->main_staff = (staff *) (staffctx->prev->data);
-	      staffs->related_staff = (staff *) (staffctx->data);
+	      staffs->main_staff = (DenemoStaff *) (staffctx->prev->data);
+	      staffs->related_staff = (DenemoStaff *) (staffctx->data);
 	      si->has_figures = staffs;
-	      ((staff *) (staffctx->data))->no_of_lines = 0;
+	      ((DenemoStaff *) (staffctx->data))->no_of_lines = 0;
 	    }
 	  break;
 
 	case voicecontext:
+	  ; // for GString
+          GString *name = gstr(g) ? gstr (g) : g_string_new ("");
 
-	  if (!findvoice (gstr (g), staffctx, si))
+
+	  if (!findvoice (name, si))
 	    {
-	      anewstaff (si, staffstruct (staffctx)->staff_name, gstr (g));
+	      anewstaff (si, staffstruct (staffctx)->staff_name, name);
+	      si->currentmeasurenum = 1;
 	      voicectx = si->currentstaff;
-	      set_denemo_name (gstr (g), staffstruct (voicectx)->denemo_name);
-	      staffstruct (voicectx)->voicenumber = 2;
+	      set_denemo_name (name, staffstruct (voicectx)->denemo_name);
+	      //staffstruct (voicectx)->voicenumber = 2;
+	      staffstruct (voicectx)->voicenumber = 1;
 	    }
 	  voicectx = si->currentstaff;
 	  break;
@@ -892,7 +1101,7 @@ create_score (scoreinfo * si, GList * top)
 	      generate_chords_and_sequentials (si, g);
 
 	      curstaffstruct->measures =
-		break_into_measures (br (g), curstaffstruct->measures);
+		break_into_measures (br (g), curstaffstruct);
 	      br (g) = (GList *) & (curstaffstruct->measures);
 	      /* nasty - we store the address
 	         of the GList* pointer. This is so that if
@@ -911,17 +1120,21 @@ create_score (scoreinfo * si, GList * top)
 	    }
 	  break;
 
+	case LYRICSTO: {
+		process_lyricsto (si, g);
+	    }
+	  break;
 
 	default:
 	  break;
-	}
+		}
     }
   return 0;
 
 }
 
 int
-create_score_from_lily (scoreinfo * si, GList * top)
+create_score_from_lily (DenemoScore * si, GList * top)
 {
   staffctx = NULL;
   voicectx = NULL;
@@ -940,9 +1153,133 @@ g_string_equal (const GString * v, const GString * v2)
     return FALSE;
   return !strcmp (v->str, v2->str);	/* not general case of embedded 0 bytes */
 }
+void
+init_crescendo_state ()
+{
+	cresc_state.active_cres = FALSE;
+	cresc_state.active_decres = FALSE;
+}
+/*
+	terminate crescendo or decrescendo if active
+*/
+static void
+terminate_crescendo_state (chord *cd)
+{
+	if (cresc_state.active_cres)
+	{
+	    cd->crescendo_end_p = TRUE;
+	    cresc_state.active_cres = FALSE;
+	}
+	if (cresc_state.active_decres)
+	{
+	    cd->diminuendo_end_p = TRUE;
+	    cresc_state.active_decres = FALSE;
+	}
+}
+
+void
+set_post_events (DenemoObject *mud, gchar *usr_str, GList *g)
+{
+    DenemoObject *obj = mud;
+    chord * chordpt;
+
+    if (!g)
+	return;
+
+    if (obj->type == SIMULTANEOUS)
+    {
+	obj = (((nodeglist*)obj)->branch)->data;
+    }
+
+    if (obj->type != CHORD)
+    {
+
+	g_assert (obj->type == CHORD);
+    }
+    chordpt = (chord *) (obj->object);
+	while (g)
+	{
+		usr_str = g_strconcat (usr_str , u_str (g), NULL);
+		switch (ntype (g)) {
+		case '(':
+			chordpt->slur_begin_p = TRUE;
+			break;
+
+		case ')':
+			chordpt->slur_end_p = TRUE;
+			break;	
+
+		case '~':
+			chordpt->is_tied = TRUE;
+			break;	
+
+		case E_SMALLER:
+			terminate_crescendo_state (chordpt);
+			chordpt->crescendo_begin_p = TRUE;
+			cresc_state.active_cres = TRUE;
+			break;
+
+		case E_BIGGER:
+			terminate_crescendo_state (chordpt);
+			chordpt->diminuendo_begin_p = TRUE;
+			cresc_state.active_decres = TRUE;
+			break;
+
+		case E_EXCLAMATION:
+			terminate_crescendo_state (chordpt);
+			break;
+
+		case TONEOPTION:
+			set_articulation (gstr (g)->str, obj);
+			break;
+
+		case DYNAMICMARK:
+		    {
+
+			/*
+			   A dynamic mark terminates crescendo or decrescendo
+			*/
+			terminate_crescendo_state (chordpt);
+
+			/*
+				\cr alternate \<
+				\decr alternate \>
+				\rc & \rced (\!) backward compatibility Denemo 
+			*/
+			if (!strcmp ( gstr (g)->str, "cr"))
+			{
+			    chordpt->crescendo_begin_p = TRUE;
+			    cresc_state.active_cres = TRUE;
+			}
+			else if (!strcmp ( gstr (g)->str, "decr"))
+			{
+			    chordpt->diminuendo_begin_p = TRUE;
+			    cresc_state.active_decres = TRUE;
+			}
+			else if (!strcmp ( gstr (g)->str, "rced")
+				 || !strcmp ( gstr (g)->str, "rc"))
+			{
+				/* we have already terminated hairpin
+				   this is so Denemo does not show these
+				   strings as dynamics */
+			}
+			else
+			
+    			    chordpt->dynamics = 
+      				g_list_append ( chordpt->dynamics, gstr (g));
+  		    }
+			break;
 
 
-#if GTK_MAJOR_VERSION > 1
+		default: g_warning ("type %d not processed in set_post_events", 
+				ntype (g));
+			break;
+		}
+	    g = g->next;
+	}
+}
+
+#ifdef LILYEDIT
 /***************** functions for managing display of lily text ***************/
 
 static void
@@ -950,7 +1287,7 @@ string_edited (GtkTextBuffer * buffer, gpointer data)
 {
   GtkTextIter start, end;
   gchar *text;
-  scoreinfo *si = (scoreinfo *) data;
+  DenemoScore *si = (DenemoScore *) data;
   gtk_text_buffer_get_bounds (buffer, &start, &end);
   text = gtk_text_iter_get_text (&start, &end);
   if (si->curlilynode == NULL)
@@ -967,7 +1304,7 @@ string_edited (GtkTextBuffer * buffer, gpointer data)
 
 
 void
-lily_text_change (scoreinfo * si)
+lily_text_change (DenemoScore * si)
 {
   static gboolean text_is_readonly = FALSE;
   g_signal_handler_block (G_OBJECT (si->textbuffer), si->sigid);
@@ -999,7 +1336,7 @@ lily_text_change (scoreinfo * si)
 
 
 void
-set_text_node (GtkWidget * button, scoreinfo * si)
+set_text_node (GtkWidget * button, DenemoScore * si)
 {
   /* FIXME: the next line can coredump when you have multiple score blocks
      and you have destroyed the textwindow and switched scores...
@@ -1011,26 +1348,9 @@ set_text_node (GtkWidget * button, scoreinfo * si)
     si->curlilynode = si->currentobject;
   lily_text_change (si);
 }
-void updatescoreinfo (struct scoreinfo *si);
-/* this is missing from header */
-void
-next_score (GtkWidget * button, scoreinfo * si)
-{
-  GList *g = si->scoreblocks;
-  if (g == NULL)
-    return;
-  /* copy the si to the last in the list si->next,
-     then copy the first to si, and then move the first to the last */
-  memcpy (g_list_last (g)->data, si, sizeof (scoreinfo));
-  memcpy (si, g->data, sizeof (scoreinfo));
-  g = g_list_append (g, g->data);	/* put it on the end */
-  g = g_list_delete_link (g, g);	/* and remove it from the beginning */
-  si->scoreblocks = g;
-  updatescoreinfo (si);
-}
 
 void
-toggle_top_node (GtkWidget * button, scoreinfo * si)
+toggle_top_node (GtkWidget * button, DenemoScore * si)
 {
   if (si->lily_file->next == NULL)
     return;			/* all in one node */
@@ -1052,7 +1372,7 @@ toggle_top_node (GtkWidget * button, scoreinfo * si)
 static void
 node_text_next (GtkWidget * win, gpointer data)
 {
-  scoreinfo *si = (scoreinfo *) data;
+  DenemoScore *si = (DenemoScore *) data;
   if (si->curlilynode == si->currentobject)
     {
       cursorright (si);
@@ -1074,7 +1394,7 @@ node_text_next (GtkWidget * win, gpointer data)
 static void
 node_text_previous (GtkWidget * win, gpointer data)
 {
-  scoreinfo *si = (scoreinfo *) data;
+  DenemoScore *si = (DenemoScore *) data;
   /*  if(si->curlilynode == NULL) si->curlilynode = lily_file; */
   if (si->curlilynode == si->currentobject)
     {
@@ -1099,7 +1419,7 @@ node_text_previous (GtkWidget * win, gpointer data)
 static void
 toggle_window (GtkWidget * widget, gpointer data)
 {
-  scoreinfo *si = (scoreinfo *) data;
+  DenemoScore *si = (DenemoScore *) data;
   /*  printf("toggling display\n"); */
   if (GTK_WIDGET_IS_SENSITIVE (si->textview))
     {
@@ -1114,10 +1434,10 @@ toggle_window (GtkWidget * widget, gpointer data)
 
 }
 
-/* create a textwindow to display the nodes in scoreinfo lily_file
+/* create a textwindow to display the nodes in DenemoScore lily_file
     */
 void
-create_text_display (scoreinfo * si)
+create_text_display (DenemoScore * si)
 {
   GtkWidget *main_vbox;
   static GtkWidget *second_window = NULL;
@@ -1210,26 +1530,27 @@ create_text_display (scoreinfo * si)
 }
 #else /* GTK version 1 */
 void
-toggle_top_node (GtkWidget * button, scoreinfo * si)
+toggle_top_node (GtkWidget * button, DenemoGUI *gui)
 {
   return;
 }
 
 void
-set_text_node (GtkWidget * button, scoreinfo * si)
+set_text_node (GtkWidget * button, DenemoGUI *gui)
 {
   return;
 }
 
 void
-lily_text_change (scoreinfo * si)
+lily_text_change (DenemoGUI *gui)
 {
   return;
 }
 
 void
-create_text_display (scoreinfo * si)
+create_text_display (DenemoGUI *gui)
 {
+  updatescoreinfo (gui->si); // RRR
   return;
 }
 #endif
