@@ -29,12 +29,12 @@
  * @param lys the actual lyric
  * @return the new lyric object
  */
-mudelaobject *
+DenemoObject *
 newlyric (gint baseduration, gint numdots, gchar * lys)
 {
-  mudelaobject *thelyric = newchord (baseduration, numdots,0);
+  DenemoObject *thelyric = newchord (baseduration, numdots, 0);
   ((chord *) thelyric->object)->lyric = g_string_new (lys);
-  ((chord *) thelyric->object)->is_syllable = FALSE;	
+  ((chord *) thelyric->object)->is_syllable = FALSE;
   set_basic_numticks (thelyric);
   return thelyric;
 }
@@ -42,7 +42,7 @@ newlyric (gint baseduration, gint numdots, gchar * lys)
 
 struct callbackdata
 {
-  struct scoreinfo *si;
+  DenemoScore *si;
   GtkWidget *entry;
   GtkWidget *extender;
   GtkWidget *center;
@@ -50,7 +50,7 @@ struct callbackdata
 
 /**
  * Lyric insertion callback function used be lyric_insert
- * @param widget the parent widget (unused)
+ * 
  * @param data callback data structure contain info about the lyric and the scoreinfo 
  * structure
  */
@@ -58,8 +58,8 @@ void
 insertlyric (gpointer data)
 {
   struct callbackdata *cbdata = (struct callbackdata *) data;
-  struct scoreinfo *si = (struct scoreinfo *) cbdata->si;
-  mudelaobject *curObj = (mudelaobject *) (si->currentobject ?
+  DenemoScore *si = (DenemoScore *) cbdata->si;
+  DenemoObject *curObj = (DenemoObject *) (si->currentobject ?
 					   si->currentobject->data : NULL);
   gchar *lyric = (gchar *) gtk_entry_get_text (GTK_ENTRY (cbdata->entry));
   if (curObj && curObj->type == CHORD)
@@ -76,17 +76,17 @@ insertlyric (gpointer data)
     }
 
   si->haschanged = TRUE;
-  gtk_widget_draw (si->scorearea, NULL);
+
 }
 
 /**
  * Insert/Edit lyric menu callback. presents user with a dialog
  * to insert the lyric
  * @param action the action event of the menuitem
- * @param si pointer to the score info structure
+ * @param gui pointer to the DenemoGUI structure
  */
 void
-lyric_insert (GtkAction * action, scoreinfo *si)
+lyric_insert (GtkAction * action, DenemoGUI * gui)
 {
   GtkWidget *dialog;
   GtkWidget *entry;
@@ -96,24 +96,23 @@ lyric_insert (GtkAction * action, scoreinfo *si)
   GtkWidget *okbutton;
   GtkWidget *cancelbutton;
   GtkWidget *table;
-  
-  static struct callbackdata cbdata;
-  mudelaobject *curObj = (mudelaobject *)
-    (si->currentobject ? si->currentobject->data : NULL);
-  if (si->lily_file)
-    return;			/* no code for this yet - just edit textually */
-  dialog = gtk_dialog_new_with_buttons (_("Insert Lyric"),
-												 GTK_WINDOW (si->window),
-												 (GtkDialogFlags) (GTK_DIALOG_MODAL |
-														 GTK_DIALOG_DESTROY_WITH_PARENT),
-												 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-												 GTK_STOCK_CANCEL, GTK_STOCK_CANCEL,
-												 NULL);
 
-		  
+  static struct callbackdata cbdata;
+  DenemoScore *si = gui->si;
+  DenemoObject *curObj = (DenemoObject *)
+    (si->currentobject ? si->currentobject->data : NULL);
+  dialog = gtk_dialog_new_with_buttons (_("Insert Lyric"),
+					GTK_WINDOW (gui->window),
+					(GtkDialogFlags) (GTK_DIALOG_MODAL |
+							  GTK_DIALOG_DESTROY_WITH_PARENT),
+					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					GTK_STOCK_CANCEL, GTK_STOCK_CANCEL,
+					NULL);
+
+
   label = gtk_label_new (_("Insert Lyric:"));
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label,
-		                         TRUE, TRUE, 0);
+		      TRUE, TRUE, 0);
   gtk_widget_show (label);
   entry = gtk_entry_new ();
   if (curObj && curObj->type == CHORD && ((chord *) curObj->object)->lyric)
@@ -123,34 +122,35 @@ lyric_insert (GtkAction * action, scoreinfo *si)
 		      0);
 
   gtk_widget_show (entry);
- 
+
   extender = gtk_check_button_new_with_label ("Extend Syllable");
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), extender,
 		      TRUE, TRUE, 0);
-  gtk_widget_show (extender); 
- 
-  center = gtk_check_button_new_with_label("Center");
+  gtk_widget_show (extender);
+
+  center = gtk_check_button_new_with_label ("Center");
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), center,
 		      TRUE, TRUE, 0);
   gtk_widget_show (center);
 
-  
+
   cbdata.si = si;
   cbdata.entry = entry;
   cbdata.extender = extender;
   cbdata.center = center;
-  
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
-  gtk_entry_set_activates_default(GTK_ENTRY(entry), TRUE);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
   gtk_widget_grab_focus (entry);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_widget_show (dialog);
-  
+
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
-  {
-	  insertlyric(&cbdata);
-  }
+    {
+      insertlyric (&cbdata);
+      displayhelper (gui);
+    }
   gtk_widget_destroy (dialog);
 
 }
