@@ -10,8 +10,8 @@
 #include <denemo/denemo.h>
 
 void insertlyric(gpointer data);
-void lyric_insert(GtkAction *action, scoreinfo *si);
-mudelaobject *
+void lyric_insert(GtkAction *action, DenemoGUI *gui);
+DenemoObject *
 newlyric (gint baseduration, gint numdots, gchar *lys);
 
 #endif
