@@ -190,20 +190,20 @@ playnotes (gboolean doit, chord chord_to_play, int prognum)
 	GList *tone;
 	SEQ_START_TIMER ();
 	/*
-	   g_list_foreach (chord_to_play.tones,
-	   (GFunc) playtone, chord_to_play.tones);
+	   g_list_foreach (chord_to_play.notes,
+	   (GFunc) playtone, chord_to_play.notes);
 	 */
-	tone = chord_to_play.tones;
+	tone = chord_to_play.notes;
 	while (tone)
 	  {
-	    playtone (tone->data, chord_to_play.tones, prognum);
+	    playtone (tone->data, chord_to_play.notes, prognum);
 	    tone = tone->next;
 	  }
 	SEQ_DELTA_TIME (50);
 
 
-	g_list_foreach (chord_to_play.tones,
-			(GFunc) stoptone, chord_to_play.tones);
+	g_list_foreach (chord_to_play.notes,
+			(GFunc) stoptone, chord_to_play.notes);
 	if (shouldremove)
 	  gtk_timeout_remove (ttag);
 	ttag = gtk_timeout_add (1000, close_seqfd, NULL);
@@ -213,7 +213,7 @@ playnotes (gboolean doit, chord chord_to_play, int prognum)
 }
 
 gint
-playsong (struct scoreinfo *si)
+playsong (DenemoScore * si)
 {
 
   return 0;
