@@ -19,4 +19,4 @@ void midi_lock ();
 
 void midi_unlock ();
 
-gint playsong (struct scoreinfo *si);
+gint playsong (DenemoScore *si);
