@@ -18,7 +18,7 @@
 
 struct callbackdata
 {
-  struct scoreinfo *si;
+  DenemoGUI *gui;
   GtkWidget *textentry;
 };
 
@@ -33,9 +33,9 @@ set_mwidth (GtkWidget * widget, gpointer data)
   gint width = atoi (gtk_entry_get_text (GTK_ENTRY (cbdata->textentry)));
 
   if (width)
-    cbdata->si->measurewidth = width;
-  adjustmeasurewidth (cbdata->si, 0);
-  gtk_widget_draw (cbdata->si->scorearea, NULL);
+    cbdata->gui->si->measurewidth = width;
+  adjustmeasurewidth (cbdata->gui->si, 0);
+  gtk_widget_queue_draw (cbdata->gui->scorearea);
 }
 
 /**
@@ -43,9 +43,8 @@ set_mwidth (GtkWidget * widget, gpointer data)
  *
  */
 void
-score_mwidth_change (GtkAction * action, gpointer callback_data)
+score_mwidth_change (GtkAction * action, DenemoGUI * gui)
 {
-  struct scoreinfo *si = (struct scoreinfo *) callback_data;
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *textentry;
@@ -66,7 +65,7 @@ score_mwidth_change (GtkAction * action, gpointer callback_data)
   gtk_widget_show (label);
 
   textentry = gtk_entry_new ();
-  g_string_sprintf (entrycontent, "%d", si->measurewidth);
+  g_string_sprintf (entrycontent, "%d", gui->si->measurewidth);
   gtk_entry_set_text (GTK_ENTRY (textentry), entrycontent->str);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
 		      textentry, TRUE, TRUE, 0);
@@ -76,7 +75,7 @@ score_mwidth_change (GtkAction * action, gpointer callback_data)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area),
 		      okbutton, TRUE, TRUE, 0);
   cbdata.textentry = textentry;
-  cbdata.si = si;
+  cbdata.gui = gui;
 
   processenter (textentry, set_mwidth, cbdata, dialog);
   gtk_signal_connect (GTK_OBJECT (okbutton), "clicked",
