@@ -7,6 +7,10 @@ void
 playback_local (gpointer callback_data, guint callback_action,
 		GtkWidget * widget);
 void
-playback (GtkAction *action, scoreinfo *si);
+ext_midi_playback (GtkAction *action, DenemoGUI *gui);
+void
+stop_midi_playback (GtkAction *action, DenemoGUI *gui);
 
+void 
+stop_midi_playback (GtkAction * action, DenemoGUI * gui);
 #endif //PLAYBACKH
