@@ -15,8 +15,8 @@
 
 struct callbackdata
 {
-  struct scoreinfo *si;
-  struct prefinfo *prefs;
+  DenemoGUI *gui;
+  DenemoPrefs *prefs;
   GtkWidget *csoundcommand;
   GtkWidget *orcfile;
   GtkWidget *rtcs;
@@ -38,8 +38,8 @@ static void
 toggle_play_staves (GtkWidget * radio_button, struct callbackdata *cbdata)
 {
   gtk_widget_set_sensitive (cbdata->staves,
-  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-	  (radio_button)));
+			    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+							  (radio_button)));
 }
 
 /**
@@ -58,33 +58,35 @@ toggle_play_measure (GtkWidget * radio_button, struct callbackdata *cbdata)
 static void
 set_preferences (struct callbackdata *cbdata)
 {
-  struct prefinfo *prefs = cbdata->prefs;
-  
+  DenemoPrefs *prefs = cbdata->prefs;
+
   g_string_assign (prefs->midiplayer,
-						 gtk_entry_get_text (GTK_ENTRY (cbdata->midiplayerentry)));
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->midiplayerentry)));
   g_string_assign (prefs->audioplayer,
-						 gtk_entry_get_text (GTK_ENTRY (cbdata->audioplayerentry)));
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->audioplayerentry)));
   g_string_assign (prefs->csoundcommand,
-						 gtk_entry_get_text (GTK_ENTRY (cbdata->csoundcommand)));
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->csoundcommand)));
+
+  if (!prefs->csoundorcfile)
+    prefs->csoundorcfile =
+      g_string_new (gtk_entry_get_text (GTK_ENTRY (cbdata->orcfile)));
+  else
+    g_string_assign (prefs->csoundorcfile,
+		     gtk_entry_get_text (GTK_ENTRY (cbdata->orcfile)));
 
-  if(!prefs->csoundorcfile)
-  		prefs->csoundorcfile= g_string_new (gtk_entry_get_text (GTK_ENTRY (cbdata->orcfile)));
-	else 
-	     g_string_assign (prefs->csoundorcfile,
-			 gtk_entry_get_text (GTK_ENTRY (cbdata->orcfile)));
-	
   prefs->rtcs =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->rtcs));
-  
+
 //  prefs->playbackoutput =
- //   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checkplayback));
-  writeXMLPrefs(prefs);
+  //   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checkplayback));
+  writeXMLPrefs (prefs);
 }
 
 
-void playback_properties_change (GtkAction * action, gpointer callback_data)
+void
+playback_properties_change (GtkAction * action, DenemoGUI * gui)
 {
-  scoreinfo *si = (struct scoreinfo *) callback_data;
+
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *table;
@@ -106,24 +108,24 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
   GtkWidget *audioplayerentry;
   GtkWidget *checkplayback;
   staffnode *n;
-  
-  
+
+
   static struct callbackdata cbdata;
-  static struct cs_callback csdata; /* for csound file selection */
+  static struct cs_callback csdata;	/* for csound file selection */
 
   dialog = gtk_dialog_new_with_buttons (_("Playback properties"),
-					GTK_WINDOW (si->window),
+					GTK_WINDOW (gui->window),
 					(GtkDialogFlags) (GTK_DIALOG_MODAL |
 							  GTK_DIALOG_DESTROY_WITH_PARENT),
 					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					NULL);
 
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE); 
-  notebook = gtk_notebook_new (); 
+  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+  notebook = gtk_notebook_new ();
 
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), notebook, TRUE,
-		                        TRUE, 0);
+		      TRUE, 0);
   table = gtk_table_new (8, 2, FALSE);
 
   gtk_container_set_border_width (GTK_CONTAINER (table), 12);
@@ -132,9 +134,9 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, NULL);
   gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), table,
-		                                        _("Playback"));
-       
-     
+				   _("Playback"));
+
+
   label = gtk_label_new (_("<b>Tempo</b>"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_FILL),
@@ -155,7 +157,8 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 		    (GtkAttachOptions) (GTK_FILL), 0, 0);
 
   tempo = gtk_spin_button_new_with_range (10.0, 250.0, 1.0);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (tempo), (gdouble) si->tempo);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (tempo),
+			     (gdouble) gui->si->tempo);
   gtk_box_pack_start (GTK_BOX (hbox), tempo, FALSE, FALSE, 0);
 
   label = gtk_label_new (_("BPM"));
@@ -203,13 +206,13 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
   gtk_box_pack_start (GTK_BOX (hbox), play_measure, FALSE, FALSE, 0);
 
   gint max_mesure =
-    g_list_length (((staff *) (si->thescore->data))->measures);
+    g_list_length (((DenemoStaff *) (gui->si->thescore->data))->measures);
 
   from_measure =
     gtk_spin_button_new_with_range (1.0, (gdouble) max_mesure, 1.0);
   gtk_box_pack_start (GTK_BOX (hbox), from_measure, TRUE, TRUE, 0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (from_measure),
-			     (gdouble) si->start);
+			     (gdouble) gui->si->start);
 
   label = gtk_label_new (_("to"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -217,9 +220,10 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
   to_measure =
     gtk_spin_button_new_with_range (1.0, (gdouble) max_mesure, 1.0);
   gtk_box_pack_start (GTK_BOX (hbox), to_measure, TRUE, TRUE, 0);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (to_measure), (gdouble) si->end);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (to_measure),
+			     (gdouble) gui->si->end);
 
-  if (si->start == 0)
+  if (gui->si->start == 0)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (play_entire_pice),
 				    TRUE);
@@ -232,7 +236,7 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
     }
 
 
-    label = gtk_label_new (_("<b>Play staves</b>"));
+  label = gtk_label_new (_("<b>Play staves</b>"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 2, 5, 6,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -271,10 +275,10 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 
   staves = gtk_combo_box_new_text ();
   gtk_box_pack_start (GTK_BOX (hbox), staves, TRUE, TRUE, 0);
-  for (n = si->thescore; n != NULL; n = g_list_next (n))
+  for (n = gui->si->thescore; n != NULL; n = g_list_next (n))
     {
       gchar *staff_label = NULL;
-      staff *s = (staff *) n->data;
+      DenemoStaff *s = (DenemoStaff *) n->data;
       if (s->staff_name != NULL)
 	{
 	  staff_label = s->staff_name->str;
@@ -290,7 +294,7 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 	}
       gtk_combo_box_append_text (GTK_COMBO_BOX (staves), staff_label);
     }
-  if (si->stafftoplay == 0)
+  if (gui->si->stafftoplay == 0)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (play_all_staves),
 				    TRUE);
@@ -300,87 +304,87 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
   else
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (play_only), TRUE);
-      gtk_combo_box_set_active (GTK_COMBO_BOX (staves), si->stafftoplay - 1);
+      gtk_combo_box_set_active (GTK_COMBO_BOX (staves),
+				gui->si->stafftoplay - 1);
     }
-  
-  cbdata.si = si;
+
+  cbdata.gui = gui;
   cbdata.play_measure = play_measure;
   cbdata.from_measure = from_measure;
   cbdata.to_measure = to_measure;
   cbdata.play_only = play_only;
   cbdata.staves = staves;
-  
+
   g_signal_connect (play_only, "toggled", G_CALLBACK (toggle_play_staves),
 		    &cbdata);
   g_signal_connect (play_measure, "toggled", G_CALLBACK (toggle_play_measure),
 		    &cbdata);
 
-  
+
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all (dialog);
 
- 
+
   /*
    * CSound Settings
    */
-	table = gtk_table_new(4,2, FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER (table), 12);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-   gtk_table_set_col_spacings (GTK_TABLE (table), 8);
-   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, NULL);
-   gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), table,
+  table = gtk_table_new (4, 2, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 12);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, NULL);
+  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), table,
 				   _("CSound Settings"));
-	label = gtk_label_new(
-   _("CSound Command:"));
+  label = gtk_label_new (_("CSound Command:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-						  (GtkAttachOptions) (GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   csoundcommand = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (csoundcommand), si->prefs->csoundcommand->str);
+  gtk_entry_set_text (GTK_ENTRY (csoundcommand),
+		      gui->prefs->csoundcommand->str);
   gtk_table_attach (GTK_TABLE (table), csoundcommand, 1, 2, 0, 1,
-						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
-	label = gtk_label_new(
-   _("Orchestra Filename:"));
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+  label = gtk_label_new (_("Orchestra Filename:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-						  (GtkAttachOptions) (GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   orcfile = gtk_entry_new ();
-  if(si->prefs->csoundorcfile)
-    gtk_entry_set_text (GTK_ENTRY (orcfile), si->prefs->csoundorcfile->str);
+  if (gui->prefs->csoundorcfile)
+    gtk_entry_set_text (GTK_ENTRY (orcfile), gui->prefs->csoundorcfile->str);
   gtk_table_attach (GTK_TABLE (table), orcfile, 1, 2, 1, 2,
-						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   csdata.entry = orcfile;
-  csdata.si = si;
+  csdata.gui = gui;
   csdata.dialog = dialog;
 
   button = gtk_button_new_with_label (_("Choose File"));
   gtk_table_attach (GTK_TABLE (table), button, 1, 2, 2, 3,
-		   (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0,
+		    0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
-	                            GTK_SIGNAL_FUNC (chooseorcfile), &csdata);
+		      GTK_SIGNAL_FUNC (chooseorcfile), &csdata);
   gtk_widget_show (button);
-	
-  
-  label = gtk_label_new(_("playback after render"));
+
+
+  label = gtk_label_new (_("playback after render"));
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
-		  				(GtkAttachOptions) (GTK_FILL),
-						(GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   gtk_widget_show (label);
-  
+
   rtcs = gtk_check_button_new ();
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rtcs),
-		                                  si->prefs->rtcs);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rtcs), gui->prefs->rtcs);
   gtk_table_attach (GTK_TABLE (table), rtcs, 1, 2, 3, 4,
-		  				(GtkAttachOptions) (GTK_FILL),
-						(GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
 
   gtk_widget_show (rtcs);
-  
+
   /*
    * Playback settings
    */
@@ -400,7 +404,7 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 
   midiplayerentry = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (midiplayerentry),
-		      si->prefs->midiplayer->str);
+		      gui->prefs->midiplayer->str);
   gtk_table_attach (GTK_TABLE (table), midiplayerentry, 1, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -413,60 +417,58 @@ void playback_properties_change (GtkAction * action, gpointer callback_data)
 
   audioplayerentry = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (audioplayerentry),
-		      si->prefs->audioplayer->str);
+		      gui->prefs->audioplayer->str);
   gtk_table_attach (GTK_TABLE (table), audioplayerentry, 1, 2, 2, 3,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
   gtk_widget_show_all (dialog);
- 
-  
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
-  
-  
-  
+
   /* Set up the callback data */
-  cbdata.prefs = si->prefs;
+  cbdata.prefs = gui->prefs;
   cbdata.midiplayerentry = midiplayerentry;
   cbdata.audioplayerentry = audioplayerentry;
   cbdata.csoundcommand = csoundcommand;
   cbdata.orcfile = orcfile;
   cbdata.rtcs = rtcs;
-  
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  gtk_entry_set_activates_default (GTK_ENTRY (tempo), TRUE);  
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
-   	 si->tempo = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tempo));
-	  //printf("\nsi->tempo = %i\n", si->tempo);
+      gui->si->tempo =
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tempo));
+      //printf("\nsi->tempo = %i\n", si->tempo);
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (play_measure)))
 	{
-	  si->start =
+	  gui->si->start =
 	    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (from_measure));
-	  si->end =
+	  gui->si->end =
 	    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (to_measure));
 	}
       else
 	{
-	  
-	  si->start = 0;
-	  si->end = 0;
+
+	  gui->si->start = 0;
+	  gui->si->end = 0;
 	}
 
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (play_only)))
 	{
-	  si->stafftoplay =
+	  gui->si->stafftoplay =
 	    1 + gtk_combo_box_get_active (GTK_COMBO_BOX (staves));
 	  //printf("\nstafftoplay = %i\n", si->stafftoplay);
 	}
       else
 	{
-	  si->stafftoplay = 0;
+	  gui->si->stafftoplay = 0;
 	  //printf("\nstafftoplay = %i\n", si->stafftoplay);
 	}
 
- 
-  	set_preferences (&cbdata); 
+
+      set_preferences (&cbdata);
     }
   gtk_widget_destroy (dialog);
 
-    
+
 }
