@@ -18,28 +18,30 @@
 #include <denemo/denemo_version.h>
 #include "prefops.h"
 #include "utils.h"
-#include "binreloc.h"
 #include "plugin.h"
 
 struct callbackdata
 {
-  struct prefinfo *prefs;
+  DenemoPrefs *prefs;
   GtkWidget *lilypathentry;
   GtkWidget *checkimmediateplayback;
   GtkWidget *checklilystyle;
+  GtkWidget *checkautosaveparts;
   GtkWidget *checkclone;
   GtkWidget *checkautosave;
   GtkWidget *checknotationpalette;
+  GtkWidget *checkrhythmpalette;
   GtkWidget *checkarticulationpalette;
   GtkWidget *autosaveentry;
   GtkWidget *browserentry;
   GtkWidget *pdfviewer;
   GtkWidget *texteditor;
+  GtkWidget *denemopath;
 };
 
 struct callbackdata1
 {
-  struct scoreinfo *si;
+  DenemoGUI *gui;
   GtkListStore *model;
 };
 
@@ -64,54 +66,57 @@ static void
 toggle_plugin (GtkCellRendererToggle * cell, gchar * path_str, gpointer data)
 {
   GtkListStore *model = ((struct callbackdata1 *) data)->model;
-  struct scoreinfo *si = ((struct callbackdata1 *) data)->si;
+  DenemoGUI *gui = ((struct callbackdata1 *) data)->gui;
   GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
   GtkTreeIter iter;
   gboolean enabled;
   gchar *plugin;
-  
+
   gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
   gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, COLUMN_LOADED, &enabled,
-							 -1);
-	
-  g_print("Path str %s \n", path_str);
-  gtk_tree_model_get(GTK_TREE_MODEL(model),&iter,COLUMN_PLUGIN, &plugin,-1 );
-   g_print("plugin %s\n", plugin);
+		      -1);
+
+  g_print ("Path str %s \n", path_str);
+  gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, COLUMN_PLUGIN, &plugin,
+		      -1);
+  g_print ("plugin %s\n", plugin);
   enabled ^= 1;
   if (enabled)
     {
-      denemo_plugin_init(plugin, si);
-     // g_warning ("TODO: Load plugin");
+      denemo_plugin_init (plugin, gui);
+      // g_warning ("TODO: Load plugin");
     }
   else
     {
-      denemo_plugin_cleanup(plugin, si);
+      denemo_plugin_cleanup (plugin, gui);
       //g_warning ("TODO: Unload plugin\n");
     }
-  
+
   gtk_list_store_set (model, &iter, COLUMN_LOADED, enabled, -1);
-  g_free(plugin);
+  g_free (plugin);
   gtk_tree_path_free (path);
 }
 
 static void
 set_preferences (struct callbackdata *cbdata)
 {
-  struct prefinfo *prefs = cbdata->prefs;
-  //static GString *localrc = NULL;
-  //FILE *fp;
-  
+  DenemoPrefs *prefs = cbdata->prefs;
+
+
   g_string_assign (prefs->lilypath,
-						 gtk_entry_get_text (GTK_ENTRY (cbdata->lilypathentry)));
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->lilypathentry)));
   g_string_assign (prefs->browser,
-						 gtk_entry_get_text (GTK_ENTRY (cbdata->browserentry)));
-  g_string_assign(prefs->pdfviewer, 
-  						gtk_entry_get_text (GTK_ENTRY (cbdata->pdfviewer)));
-  g_string_assign(prefs->texteditor, 
-  						gtk_entry_get_text (GTK_ENTRY (cbdata->texteditor)));
-    prefs->immediateplayback =
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->browserentry)));
+  g_string_assign (prefs->pdfviewer,
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->pdfviewer)));
+  g_string_assign (prefs->texteditor,
+		   gtk_entry_get_text (GTK_ENTRY (cbdata->texteditor)));
+  g_string_assign (prefs->denemopath,
+                   gtk_entry_get_text (GTK_ENTRY (cbdata->denemopath)));
+
+  prefs->immediateplayback =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-											 (cbdata->checkimmediateplayback));
+				  (cbdata->checkimmediateplayback));
   prefs->lilyentrystyle =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checklilystyle));
   prefs->createclones =
@@ -122,21 +127,28 @@ set_preferences (struct callbackdata *cbdata)
   prefs->autosave_timeout =
     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
 				      (cbdata->autosaveentry));
-	
-  prefs->articulation_palette = 
-  	 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checkarticulationpalette));
-   prefs->notation_palette = 
-  	 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checknotationpalette));
-  
+
+  prefs->articulation_palette =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+				  (cbdata->checkarticulationpalette));
+  prefs->notation_palette =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+				  (cbdata->checknotationpalette));
+  prefs->rhythm_palette =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+				  (cbdata->checkrhythmpalette));
+  prefs->saveparts =
+  	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
+  				  (cbdata->checkautosaveparts));
   g_print ("Timeout %d \n", prefs->autosave_timeout);
-  
+
   /* Now write it all to denemorc */
-    writeXMLPrefs(prefs);
- 
+  writeXMLPrefs (prefs);
+
 }
 
 void
-preferences_change (GtkAction * action, struct scoreinfo *si)
+preferences_change (GtkAction * action, DenemoGUI * gui)
 {
   GtkWidget *dialog;
   GtkWidget *label;
@@ -145,12 +157,15 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   GtkWidget *browserentry;
   GtkWidget *checkimmediateplayback;
   GtkWidget *checklilystyle;
+  GtkWidget	*checkautosaveparts;
   GtkWidget *checkclone;
   GtkWidget *checkautosave;
   GtkWidget *autosaveentry;
   GtkWidget *pdfviewer;
   GtkWidget *texteditor;
+  GtkWidget *denemopath;
   GtkWidget *checknotationpalette;
+  GtkWidget *checkrhythmpalette;
   GtkWidget *checkarticulationpalette;
   GtkWidget *notebook;
   GtkWidget *hbox;
@@ -162,10 +177,10 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   GtkCellRenderer *renderer;
   static struct callbackdata cbdata;
   static struct callbackdata1 cbdata1;
-  g_assert (si != NULL);
+  g_assert (gui != NULL);
 
   dialog = gtk_dialog_new_with_buttons (_("Preferences - Denemo"),
-					GTK_WINDOW (si->window),
+					GTK_WINDOW (gui->window),
 					(GtkDialogFlags) (GTK_DIALOG_MODAL |
 							  GTK_DIALOG_DESTROY_WITH_PARENT),
 					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -181,7 +196,7 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   /*
    * Note entry settings
    */
-  table = gtk_table_new (8, 2, FALSE);
+  table = gtk_table_new (13, 2, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (table), 12);
   gtk_table_set_row_spacings (GTK_TABLE (table), 8);
   gtk_table_set_col_spacings (GTK_TABLE (table), 8);
@@ -190,11 +205,12 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), table,
 				   _("Entry"));
 
-  
+
   checkimmediateplayback =
-    gtk_check_button_new_with_label (_("Play back entered notes immediately"));
+    gtk_check_button_new_with_label (_
+				     ("Play back entered notes immediately"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkimmediateplayback),
-				si->prefs->immediateplayback);
+				gui->prefs->immediateplayback);
   gtk_table_attach (GTK_TABLE (table), checkimmediateplayback, 0, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0,
 		    0);
@@ -204,7 +220,7 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   /* Comment that out when the feature is added */
   gtk_widget_set_sensitive (checklilystyle, FALSE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checklilystyle),
-				si->prefs->lilyentrystyle);
+				gui->prefs->lilyentrystyle);
   gtk_table_attach (GTK_TABLE (table), checklilystyle, 0, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -213,41 +229,57 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
     gtk_check_button_new_with_label (_("Clone chords when tying them"));
   gtk_widget_set_sensitive (checkclone, FALSE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkclone),
-				si->prefs->createclones);
+				gui->prefs->createclones);
   gtk_table_attach (GTK_TABLE (table), checkclone, 0, 2, 2, 3,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
-  checknotationpalette = gtk_check_button_new_with_label (_("Display notataion toolbar"));
+  checknotationpalette =
+    gtk_check_button_new_with_label (_("Display durations toolbar"));
   gtk_widget_set_sensitive (checknotationpalette, TRUE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checknotationpalette),
-				si->prefs->notation_palette);
+				gui->prefs->notation_palette);
   gtk_table_attach (GTK_TABLE (table), checknotationpalette, 0, 2, 4, 5,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-		    
-  checkarticulationpalette = gtk_check_button_new_with_label (_("Display articulation palette"));
+
+  checkarticulationpalette =
+    gtk_check_button_new_with_label (_("Display articulation palette"));
   gtk_widget_set_sensitive (checkarticulationpalette, TRUE);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkarticulationpalette),
-				si->prefs->articulation_palette);
+				gui->prefs->articulation_palette);
   gtk_table_attach (GTK_TABLE (table), checkarticulationpalette, 0, 2, 6, 7,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
-		     
+
+
+  checkrhythmpalette =
+    gtk_check_button_new_with_label (_("Display rhythm pattern toolbar"));
+  gtk_widget_set_sensitive (checkrhythmpalette, TRUE);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkrhythmpalette),
+				gui->prefs->rhythm_palette);
+  gtk_table_attach (GTK_TABLE (table), checkrhythmpalette, 0, 2, 8, 9,
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+
+
+
+
   hbox = gtk_hbox_new (FALSE, 8);
-  gtk_table_attach (GTK_TABLE (table), hbox, 0, 2, 7, 8,
+  gtk_table_attach (GTK_TABLE (table), hbox, 0, 2, 10, 11,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
   checkautosave = gtk_check_button_new_with_label (_("Autosave every"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosave),
-				si->prefs->autosave);
+				gui->prefs->autosave);
   gtk_box_pack_start (GTK_BOX (hbox), checkautosave, FALSE, FALSE, 0);
 
   autosaveentry = gtk_spin_button_new_with_range (1, 50, 1.0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (autosaveentry),
-			     si->prefs->autosave_timeout);
-  gtk_widget_set_sensitive (autosaveentry, si->prefs->autosave);
+			     gui->prefs->autosave_timeout);
+  gtk_widget_set_sensitive (autosaveentry, gui->prefs->autosave);
   gtk_box_pack_start (GTK_BOX (hbox), autosaveentry, FALSE, FALSE, 0);
 
   label = gtk_label_new (_("minute(s)"));
@@ -256,6 +288,13 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
 		    "toggled", G_CALLBACK (toggle_autosave), autosaveentry);
 
 
+  checkautosaveparts = gtk_check_button_new_with_label(_("Autosave Parts"));
+  gtk_widget_set_sensitive (checkarticulationpalette, FALSE);
+   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosaveparts),
+				gui->prefs->saveparts);
+  gtk_table_attach(GTK_TABLE(table), checkautosaveparts, 0,2, 11,12,
+  				   (GtkAttachOptions) (GTK_FILL),
+  				   (GtkAttachOptions) (0), 0,0);
   /*
    * External (Helper) Programs 
    */
@@ -275,34 +314,47 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
 		    (GtkAttachOptions) (0), 0, 0);
 
   lilypathentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (lilypathentry), si->prefs->lilypath->str);
+  gtk_entry_set_text (GTK_ENTRY (lilypathentry), gui->prefs->lilypath->str);
   gtk_table_attach (GTK_TABLE (table), lilypathentry, 1, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
 
-  label = gtk_label_new(_("Pdf Viewer"));
-  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1,2 ,
-  						(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		    			(GtkAttachOptions) (0), 0, 0);
+  label = gtk_label_new (_("Pdf Viewer"));
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   pdfviewer = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (pdfviewer), si->prefs->pdfviewer->str);
-  gtk_table_attach(GTK_TABLE(table), pdfviewer, 1, 2, 1,2 ,
-  						(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		    			(GtkAttachOptions) (0), 0, 0);
+  gtk_entry_set_text (GTK_ENTRY (pdfviewer), gui->prefs->pdfviewer->str);
+  gtk_table_attach (GTK_TABLE (table), pdfviewer, 1, 2, 1, 2,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
 
-  label = gtk_label_new(_("Text Edtior"));
-  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2,3 ,
-  						(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		    			(GtkAttachOptions) (0), 0, 0);
+  label = gtk_label_new (_("Text Edtior"));
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
 
   texteditor = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (texteditor), si->prefs->texteditor->str);
-  gtk_table_attach(GTK_TABLE(table), texteditor, 1, 2, 2,3 ,
-  						(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		    			(GtkAttachOptions) (0), 0, 0);
+  gtk_entry_set_text (GTK_ENTRY (texteditor), gui->prefs->texteditor->str);
+  gtk_table_attach (GTK_TABLE (table), texteditor, 1, 2, 2, 3,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+
+  label = gtk_label_new (_("Default Save Path"));
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+  denemopath = gtk_entry_new ();
+  if (gui->prefs->denemopath != NULL)
+  	gtk_entry_set_text (GTK_ENTRY (denemopath), gui->prefs->denemopath->str);
+  gtk_table_attach (GTK_TABLE (table), denemopath, 1, 2, 3, 4,
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
 
-  
   /*
    * Plugins settings
    */
@@ -314,10 +366,10 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
 
   list_store = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
 
-  if (si->plugins)
+  if (gui->plugins)
     {
-	    GList *tmp;
-      for (tmp = si->plugins; tmp; tmp = tmp->next)
+      GList *tmp;
+      for (tmp = gui->plugins; tmp; tmp = tmp->next)
 	{
 	  gtk_list_store_append (list_store, &iter);
 	  gtk_list_store_set (list_store, &iter,
@@ -330,22 +382,20 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
     }
 
   GList *plugins = NULL;
-  plugins = get_plugins_list(plugins);
+  plugins = get_plugins_list (plugins);
   if (plugins)
-  {
-	  GList *tmp;
-	  g_print("list of plugins is populated\n");
-	  for(tmp=plugins; tmp; tmp=tmp->next)
-	  {
-		  gtk_list_store_append (list_store, &iter);
-		  gtk_list_store_set (list_store, &iter,
+    {
+      GList *tmp;
+      g_print ("list of plugins is populated\n");
+      for (tmp = plugins; tmp; tmp = tmp->next)
+	{
+	  gtk_list_store_append (list_store, &iter);
+	  gtk_list_store_set (list_store, &iter,
 			      COLUMN_LOADED, FALSE,
-			      COLUMN_PLUGIN,
-			      (gchar *) tmp->data,
-			      -1);
-	  }
-  }
-  
+			      COLUMN_PLUGIN, (gchar *) tmp->data, -1);
+	}
+    }
+
   gtk_list_store_append (list_store, &iter);
   gtk_list_store_set (list_store, &iter,
 		      COLUMN_LOADED, FALSE,
@@ -359,7 +409,7 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
   gtk_box_pack_start (GTK_BOX (vbox), tree, TRUE, TRUE, 0);
   g_object_unref (G_OBJECT (list_store));
-  cbdata1.si = si;
+  cbdata1.gui = gui;
   cbdata1.model = list_store;
   renderer = gtk_cell_renderer_toggle_new ();
   g_signal_connect (renderer, "toggled", G_CALLBACK (toggle_plugin),
@@ -375,7 +425,7 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
 						     COLUMN_PLUGIN, NULL);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
-  
+
   /*
    * Help settings
    */
@@ -391,37 +441,41 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   label = gtk_label_new (_("Help Browser:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-						  (GtkAttachOptions) (GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
   browserentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (browserentry), si->prefs->browser->str);
+  gtk_entry_set_text (GTK_ENTRY (browserentry), gui->prefs->browser->str);
   gtk_table_attach (GTK_TABLE (table), browserentry, 1, 2, 0, 1,
-						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
-  
-  
+		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		    (GtkAttachOptions) (0), 0, 0);
+
+
 
   /* Set up the callback data */
-  cbdata.prefs = si->prefs;
+  cbdata.prefs = gui->prefs;
   cbdata.lilypathentry = lilypathentry;
   cbdata.checkimmediateplayback = checkimmediateplayback;
   cbdata.checklilystyle = checklilystyle;
+  cbdata.checkautosaveparts = checkautosaveparts;
   cbdata.checkarticulationpalette = checkarticulationpalette;
   cbdata.checknotationpalette = checknotationpalette;
+  cbdata.checkrhythmpalette = checkrhythmpalette;
   cbdata.checkclone = checkclone;
   cbdata.checkautosave = checkautosave;
   cbdata.autosaveentry = autosaveentry;
   cbdata.browserentry = browserentry;
   cbdata.pdfviewer = pdfviewer;
   cbdata.texteditor = texteditor;
-  
-  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
-  gtk_entry_set_activates_default(GTK_ENTRY(lilypathentry), TRUE);
-  gtk_entry_set_activates_default(GTK_ENTRY(autosaveentry), TRUE);
-  gtk_entry_set_activates_default(GTK_ENTRY(browserentry), TRUE);
-  gtk_entry_set_activates_default(GTK_ENTRY(pdfviewer), TRUE);
-  gtk_entry_set_activates_default(GTK_ENTRY(texteditor), TRUE);
+  cbdata.denemopath = denemopath;
 
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  gtk_entry_set_activates_default (GTK_ENTRY (lilypathentry), TRUE);
+  gtk_entry_set_activates_default (GTK_ENTRY (autosaveentry), TRUE);
+  gtk_entry_set_activates_default (GTK_ENTRY (browserentry), TRUE);
+  gtk_entry_set_activates_default (GTK_ENTRY (pdfviewer), TRUE);
+  gtk_entry_set_activates_default (GTK_ENTRY (texteditor), TRUE);
+  gtk_entry_set_activates_default (GTK_ENTRY (denemopath), TRUE);
+  
   gtk_widget_grab_focus (lilypathentry);
   gtk_widget_show_all (dialog);
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
@@ -431,28 +485,25 @@ preferences_change (GtkAction * action, struct scoreinfo *si)
   gtk_widget_destroy (dialog);
 }
 
-GList *get_plugins_list(GList *plugins)
+GList *
+get_plugins_list (GList * plugins)
 {
-	
-	DIR *dir;
-   struct dirent *dirent;
-   char *name;
-   gchar *dirname;
-	dirname = gbr_find_lib_dir(PACKAGE_PLUGIN_DIR);
-   //dirname = g_strconcat(dirname, "/denemo/", NULL);
-	g_print("Directory %s\n",dirname);
-   dir = opendir (dirname);
-	
-   if (!dir)
-     return NULL;
+  DIR *dir;
+  struct dirent *dirent;
+  char *name;
+  //dirname = g_strconcat(dirname, "/denemo/", NULL);
+  g_print ("Directory %s\n", get_plugin_dir ());
+  dir = opendir (get_plugin_dir ());
 
-   while ((dirent = readdir (dir)) != NULL)
+  if (!dir)
+    return NULL;
+
+  while ((dirent = readdir (dir)) != NULL)
     {
-		g_print("Filename is %s\n", dirent->d_name);
+      g_print ("Filename is %s\n", dirent->d_name);
       if ((name = stripname (dirent->d_name)) != NULL)
-			plugins = g_list_append(plugins, name);
-	 }
-	 
-	 g_free(dirname);
-	 return(plugins);
+	plugins = g_list_append (plugins, name);
+    }
+
+  return (plugins);
 }
