@@ -6,11 +6,11 @@
 
 #include "runsilent.h"
 #include "importxml.h"
-#include "exportmudela.h"
+#include "exportlilypond.h"
 #include <string.h>
 
 void
-silentconversion (char *file_in, struct scoreinfo *si)
+silentconversion (char *file_in, DenemoScore * si)
 {
   int result;
   char *file_out;
@@ -22,6 +22,6 @@ silentconversion (char *file_in, struct scoreinfo *si)
     }
 
   file_out = "silentconversion.ly";
-  exportmudela ((gchar *) file_out, si, 0, 0);
+  exportlilypond ((gchar *) file_out, si, 0, 0);
   printf ("\nWritten to %s\n\n", file_out);
 };
