@@ -12,21 +12,36 @@
 #define INITIAL_STAFFHEIGHT 100
 
 
+/**
+ * Create new DenemoScore
+ * 
+ */
+DenemoScore *
+new_score (gchar *lilyversion)
+{
+  DenemoScore *newscore = (DenemoScore *) g_malloc0 (sizeof (DenemoScore));
+  init_score (newscore, lilyversion);
+
+  return newscore;
+}
+
+
 /**
  * Initialise scoreinfo structure 
  *
  * @param si pointer to the scoreinfo structure to initialise
  */
 void
-init_score (struct scoreinfo *si)
+init_score (DenemoScore * si, gchar * lilyversion)
 {
+  gchar *dir = locatedotdenemo ();
   si->readonly = 0;
   si->leftmeasurenum = si->rightmeasurenum = 1;
   si->top_staff = si->bottom_staff = 1;
   si->measurewidth = INITIAL_WHOLEWIDTH;
   si->measurewidths = NULL;
   si->staffspace = INITIAL_STAFFHEIGHT;
-	si->config = NULL;
+  si->config = NULL;
   si->thescore = NULL;
   si->currentstaffnum = 1;
   si->currentmeasurenum = 1;
@@ -35,8 +50,9 @@ init_score (struct scoreinfo *si)
   si->cursor_y = 0;
   si->staffletter_y = 0;
   si->cursor_appending = TRUE;
-  si->mode = INPUTNORMAL;
+
   si->cursoroffend = FALSE;
+  si->cursortime1=si->cursortime2=4;
   si->markstaffnum = 0;
   si->markmeasurenum = 0;
   si->markcursor_x = 0;
@@ -44,6 +60,7 @@ init_score (struct scoreinfo *si)
   si->haschanged = FALSE;
   si->is_grace_mode = FALSE;
   si->has_figures = FALSE;
+  si->has_fakechords = FALSE;
   /*playback purposes */
   si->tempo = 60;
   si->start = 0;
@@ -51,26 +68,22 @@ init_score (struct scoreinfo *si)
   si->stafftoplay = 0;
 
   si->savebuffer = NULL;
-  si->plugins = NULL;
-  si->plugincounter = 0;
   si->bookmarks = NULL;
 
   si->headerinfo = new_mudela_header ();
 
   si->filename = g_string_new ("");
-  si->autosavename = NULL;
-  si->textbuffer = 0;		/* text of lily input string corresponding to curobj */
-  si->textwindow = 0;		/* top level window containing lily text */
-  si->curlilynode = 0;		/* the node of the lily parse tree on display in 
-				   textwindow */
-  si->lily_file = 0;		/* root of lily file parse, see lilyparser.y etc  */
-  si->sconfig = new_score_config();
+  si->autosavename = g_string_new (dir);
+  si->autosavename = g_string_append (si->autosavename, "/autosave.denemo");
+
+  si->curlilynode = 0;	 /* the node of the lily parse tree on display in 
+			    textwindow */
+  si->lily_file = 0;   /* root of lily file parse, see lilyparser.y etc  */
+  si->sconfig = new_score_config (lilyversion);
   /* Undo/redo initialisation */
-  si->undodata = g_queue_new();
-  si->undo_level = 0;
-  si->redodata = g_queue_new();
-  si->redo_level = 0;
-  si->undo_redo_mode = 1;
+  si->undodata = g_queue_new ();
+  si->redodata = g_queue_new ();
+  si->undo_redo_mode = UNDO;
 }
 
 
@@ -80,11 +93,11 @@ init_score (struct scoreinfo *si)
  * @param si pointer to the scoreinfo structure to initialise
  */
 void
-free_score (struct scoreinfo *si)
+free_score (DenemoScore * si)
 {
   gint final = (gint) (g_list_length (si->thescore));
-  if (si->lily_file != NULL)
-    abandon_lily_tree (si);
+/*  if (si->lily_file != NULL)
+  abandon_lily_tree (si);*/
   for (; final == 0; --final)
     {
       si->currentstaffnum = final;
@@ -96,22 +109,29 @@ free_score (struct scoreinfo *si)
      g_string_free (si->composer, FALSE);
      g_string_free (si->filename, FALSE); */
   /* what's up with this ? dlp wants to know... */
-  init_score (si);
+
+  g_free (si->sconfig);
+  free_lilypond_header(si->headerinfo);
+  g_free (si->headerinfo);
+  si->headerinfo=NULL;
+  g_queue_free (si->undodata);
+  g_queue_free (si->redodata);
+  init_score (si, NULL);
 }
 
 /**
  * Destroy the lilypond mode text view of the score
  */
 void
-abandon_lily_tree (scoreinfo * si)
+abandon_lily_tree (DenemoGUI * gui)
 {
 
-  if (si->textwindow)
-    gtk_widget_destroy (si->textwindow);
+  if (gui->textwindow)
+    gtk_widget_destroy (gui->textwindow);
   /* FIXME memory leak */
-  si->lily_file = NULL;
-  si->textwindow = NULL;
-  si->scoreblocks = NULL;	/* FIXME memory leak */
+  gui->si->lily_file = NULL;
+  gui->textwindow = NULL;
+  gui->si->scoreblocks = NULL;	/* FIXME memory leak */
 }
 
 /**
@@ -119,13 +139,12 @@ abandon_lily_tree (scoreinfo * si)
  * 
  * @return the newly created mudela_header structure
  */
-struct mudelaheaderinfo *
+LilypondHeaderInfo *
 new_mudela_header ()
 {
-  struct mudelaheaderinfo *head;
+  LilypondHeaderInfo *head=NULL;
 
-  head = (struct mudelaheaderinfo *)
-    g_malloc0 (sizeof (struct mudelaheaderinfo));
+  head = (LilypondHeaderInfo *) g_malloc0 (sizeof (LilypondHeaderInfo));
 
   /* Header info */
   head->title = g_string_new ("");
@@ -148,20 +167,38 @@ new_mudela_header ()
 
 }
 
+void free_lilypond_header(LilypondHeaderInfo *head)
+{
+  g_string_free(head->title, TRUE);
+  g_string_free(head->subtitle, TRUE);
+  g_string_free(head->poet, TRUE);
+  g_string_free(head->composer, TRUE);
+  g_string_free(head->meter, TRUE);
+  g_string_free(head->opus, TRUE);
+  g_string_free(head->arranger, TRUE);
+  g_string_free(head->instrument, TRUE);
+  g_string_free(head->dedication, TRUE);
+  g_string_free(head->copyright, TRUE);
+  g_string_free(head->footer, TRUE);
+  g_string_free(head->tagline, TRUE);
+  
+}
+
 /**
  * Create and initialise the score config struture
  *
  * @return the newly created score config structure
  */
-scoreconfig *
-new_score_config()
+DenemoScoreConfig *
+new_score_config (gchar * lilyversion)
 {
-	scoreconfig *config = (scoreconfig *) g_malloc0(sizeof(scoreconfig));
-	
-	config->papersize = g_string_new("a4"); //A4 default
-	config->fontsize = 16;
-	config->lilyversion = g_string_new("2.6.0");
-	config->orientation = TRUE;  //portrait
+  DenemoScoreConfig *config =
+    (DenemoScoreConfig *) g_malloc0 (sizeof (DenemoScoreConfig));
 
-   return config;
+  config->papersize = g_string_new ("a4");	//A4 default
+  config->fontsize = 16;
+  config->lilyversion = g_string_new (lilyversion);
+  config->orientation = TRUE;	//portrait
+
+  return config;
 }
