@@ -1,9 +1,12 @@
 /**
- * selectops.cpp
+ * selectops.c
  * operations for selecting, cutting, copying, and pasting music
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (c) 1999-2005 Matthew Hiller, Adam Tee */
+ * (c) 1999-2005 Matthew Hiller, Adam Tee 
+ *
+ * TODO: Fix Undo/Redo
+ */
 
 #include <string.h>
 #include "calculatepositions.h"
@@ -18,6 +21,7 @@
 /*For save selection function*/
 #include "frogio.h"
 #include "utils.h"
+
 /**
  * The copy buffer is a GList of objnode *s -- at first, I was going
  * to use staffnode *s, measurenode *s, and then objnode *s, but I
@@ -28,6 +32,10 @@
  * the buffer on each staff.  
  */
 
+static void
+undo (DenemoGUI * gui);
+static void
+redo (DenemoGUI * gui);
 static GList *copybuffer = NULL;
 
 static gint staffsinbuffer = 0;
@@ -38,11 +46,15 @@ static gint measurebreaksinbuffer = 0;
  *  sets current object to the given cursor position
  * 
  */
-void setcurrentobject(scoreinfo *si, gint cursorpos)
+void
+setcurrentobject (DenemoScore * si, gint cursorpos)
 {
-	g_print("Set Current Object Cursor pos %d\n",cursorpos); 
-	si->currentobject = g_list_nth( (objnode *)si->currentmeasure->data, cursorpos);
-	g_print("Current Object %x, Data %x\n", si->currentobject, si->currentobject->data);
+
+  g_debug ("Set Current Object Cursor pos %d\n", cursorpos);
+
+  si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
+				  cursorpos);
+  g_assert (si->currentobject != NULL);
 }
 
 /**
@@ -66,14 +78,12 @@ clearbuffer ()
  *  saveselection 
  *  Saves the current selection to a given file
  * 
- *  Input - struct scoreinfo -  score information
- *  Return - None
+ *  @param si pointer to the score information structure
+ *  @return none
  */
 void
-saveselection (struct scoreinfo *si)
+saveselection (DenemoScore * si)
 {
-
-
   if (si->markstaffnum == 0)	/* Indicator that there's no selection.  */
     return;
 
@@ -99,16 +109,16 @@ saveselection (struct scoreinfo *si)
  *   copytobuffer
  *   Copies selection to the copybuffer
  *   
- *   Input - struct scoreinfo - score information
+ *   @param si pointer to the score information structure
  */
 void
-copytobuffer (struct scoreinfo *si)
+copytobuffer (DenemoScore * si)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
   objnode *curobj;
   objnode *theobjs;
-  mudelaobject *clonedobject;
+  DenemoObject *clonedobject;
   gint i, j, k;
 
   if (si->markstaffnum == 0)	/* Indicator that there's no selection.  */
@@ -117,11 +127,12 @@ copytobuffer (struct scoreinfo *si)
   clearbuffer ();
 
   staffsinbuffer = si->laststaffmarked - si->firststaffmarked + 1;
+  g_debug ("No staffs in copybuffer %d\n", staffsinbuffer);
   /* Staff loop.  */
   for (i = si->firststaffmarked, curstaff = g_list_nth (si->thescore, i - 1);
        curstaff && i <= si->laststaffmarked; curstaff = curstaff->next, i++)
     {
-      if (((staff *) curstaff->data)->is_parasite)
+      if (((DenemoStaff *) curstaff->data)->is_parasite)
 	continue;
       /* Initialize first ->data for copybuffer to NULL.  */
       theobjs = NULL;
@@ -137,12 +148,18 @@ copytobuffer (struct scoreinfo *si)
 			  || k <= si->lastobjmarked);
 	       curobj = curobj->next, k++)
 	    {
-	      clonedobject = clone_object ((mudelaobject *) curobj->data);
+	      clonedobject = dnm_clone_object ((DenemoObject *) curobj->data);
 	      theobjs = g_list_append (theobjs, clonedobject);
 	    }			/* End object loop */
-	  if (j < si->lastmeasuremarked || k < si->lastobjmarked
-	      || staffsinbuffer > 1)
+	  g_debug ("cloned objects on staff \n");
+	  if (staffsinbuffer > 1)
 	    {
+	      theobjs = g_list_append (theobjs, newstaffbreakobject ());
+	      g_debug ("Inserting Staffbreak object in copybuffer");
+	    }
+	  else if (j < si->lastmeasuremarked || k < si->lastobjmarked)
+	    {
+	      g_debug ("Insert measurebreak obj in copybuffer");
 	      /* That is, there's another measure, the cursor is in appending
 	         position, or the selection spans multiple staffs, in which 
 	         case another measure boundary should be added.  */
@@ -151,19 +168,22 @@ copytobuffer (struct scoreinfo *si)
 		measurebreaksinbuffer++;
 	    }
 	  k = 0;		/* Set it for next run through object loop */
+
 	}			/* End measure loop */
+
       copybuffer = g_list_append (copybuffer, theobjs);
     }				/* End staff loop */
 }
 
+
 /**
  *  cuttobuffer
  *  Cuts selection to the copybuffer, removing it from the score
  *
- *  Input - struct scoreinfo - score information
+ *  @param si pointer to score information structure
  */
 void
-cuttobuffer (struct scoreinfo *si)
+cuttobuffer (DenemoScore * si)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
@@ -190,7 +210,7 @@ cuttobuffer (struct scoreinfo *si)
 	{
 	  curmeasure->data =
 	    g_list_remove_link ((objnode *) curmeasure->data, tempobj);
-	  freeobject ((mudelaobject *) tempobj->data);
+	  freeobject ((DenemoObject *) tempobj->data);
 	  g_list_free_1 (tempobj);
 	}
       j++;
@@ -202,7 +222,7 @@ cuttobuffer (struct scoreinfo *si)
 	  if (measurebreaksinbuffer - 1 > 0)
 	    {
 	      curmeasure =
-		removemeasures (si, j - 1, measurebreaksinbuffer - 1);
+		removemeasures (si, j - 1, measurebreaksinbuffer - 1, TRUE);
 	      j += measurebreaksinbuffer - 1;
 	    }
 	}
@@ -221,16 +241,16 @@ cuttobuffer (struct scoreinfo *si)
 	      tempobj = (objnode *) curmeasure->data;
 	      curmeasure->data =
 		g_list_remove_link ((objnode *) curmeasure->data, tempobj);
-	      freeobject ((mudelaobject *) tempobj->data);
+	      freeobject ((DenemoObject *) tempobj->data);
 	      g_list_free_1 (tempobj);
 	    }
 	  /* And delete it, if the measure's been cleared and there's only
 	     one staff.  */
 	  if (!curmeasure->data && !si->thescore->next)
-	    removemeasures (si, j - 1, 1);
+	    removemeasures (si, j - 1, 1, TRUE);
 	}
-      showwhichaccidentalswholestaff ((staff *) si->currentstaff->data);
-      beamsandstemdirswholestaff ((staff *) si->currentstaff->data);
+      showwhichaccidentalswholestaff ((DenemoStaff *) si->currentstaff->data);
+      beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
     }
   else
     {				/* Multiple staff selection */
@@ -239,11 +259,11 @@ cuttobuffer (struct scoreinfo *si)
 	  /* Every staff was part of the selection */
 	  if (measurebreaksinbuffer > 0)
 	    removemeasures (si, si->firstmeasuremarked - 1,
-			    measurebreaksinbuffer);
+			    measurebreaksinbuffer, TRUE);
 	  for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
 	    {
-	      showwhichaccidentalswholestaff ((staff *) curstaff->data);
-	      beamsandstemdirswholestaff ((staff *) curstaff->data);
+	      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+	      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
 	    }
 	}
       else
@@ -254,7 +274,7 @@ cuttobuffer (struct scoreinfo *si)
 	       curstaff && i <= si->laststaffmarked;
 	       curstaff = curstaff->next, i++)
 	    {
-	      if (((staff *) curstaff->data)->is_parasite)
+	      if (((DenemoStaff *) curstaff->data)->is_parasite)
 		continue;
 	      /* Measure loop */
 	      for (j = si->firstmeasuremarked,
@@ -266,15 +286,15 @@ cuttobuffer (struct scoreinfo *si)
 		  freeobjlist (curmeasure->data, NULL);
 		  curmeasure->data = NULL;
 		}
-	      showwhichaccidentalswholestaff ((staff *) curstaff->data);
-	      beamsandstemdirswholestaff ((staff *) curstaff->data);
+	      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+	      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
 	    }
 	}
     }
   si->markstaffnum = 0;
   /* And set some currents. This would probably be better to split off
    * into a more-generalized version of setcurrents or something;
-   * what's here is more-or-less copied from deleteobject in
+   * what's here is more-or-less copied from dnm_deleteobject in
    * commandfuncs */
 
   si->currentmeasurenum = si->firstmeasuremarked;
@@ -294,16 +314,16 @@ cuttobuffer (struct scoreinfo *si)
       si->cursor_appending = TRUE;
     }
   /*   isoffleftside;  */
-  find_xes_in_all_measures (si);
-  nudgerightward (si);
-  gtk_widget_draw (si->scorearea, NULL);
+  /*find_xes_in_all_measures (si);
+     nudgerightward (si);
+     gtk_widget_draw (si->scorearea, NULL); */
 }
 
-/** 
+/**
  * pastefrombuffer
  * Pastes the current buffer to the score
  *
- * Inputs - struct scoreinfo - score information
+ * @param si pointer to the score information structure
  *
  * The updates that are done towards the bottom of this function -
  * beamsandstemdirswholestaff, find_xes_in_all_measures, etc. - are
@@ -312,40 +332,18 @@ cuttobuffer (struct scoreinfo *si)
  */
 
 void
-pastefrombuffer (struct scoreinfo *si)
+pastefrombuffer (DenemoScore * si)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
   GList *curbuffernode = copybuffer;
   objnode *curbufferobj;
   gint insertat, initialinsertat;
-  mudelaobject *clonedobject;
-  /*   gboolean clefflag = FALSE;
-     gboolean timesigflag = FALSE;
-     gboolean keysigflag = FALSE; */
-  gint i, initialj, j;
+  DenemoObject *clonedobject;
+
+  gint i, j;
   gint measurestoadd = 0;
 
-  /* First, check to see if the insertion is taking place only in
-   * blank measures. If not, insert as many measures as is appropriate. */
-
-  initialj = (staffsinbuffer == 1 && si->cursor_x);
-  /* for (i = 0, curstaff = si->currentstaff;
-       curstaff && i < staffsinbuffer; curstaff = curstaff->next, i++)
-    for (j = initialj,
-  curmeasure = g_list_nth (firstmeasurenode (curstaff),
-  		  si->currentmeasurenum - 1 + j);
-  curmeasure && j < measurebreaksinbuffer;
-  curmeasure = curmeasure->next, j++)
-      if (curmeasure->data || !curmeasure->next)
-  {			/* A-ha! This measure has something in it! 
-   measurestoadd = measurebreaksinbuffer - initialj;
-   goto out;		/* Multilevel break, essentially 
-  }
-  out:*/
- // if ((measurebreaksinbuffer - initialj) > 0)
-   // addmeasures (si, si->currentmeasurenum - 1 + initialj,(measurebreaksinbuffer - initialj) );
-
   /* All right. Any necessary measures have been inserted - now paste away */
 
   if (staffsinbuffer == 1)
@@ -353,61 +351,96 @@ pastefrombuffer (struct scoreinfo *si)
   else
     initialinsertat = 0;
 
+  g_debug ("Insert At position %d\n", initialinsertat);
+
   for (curstaff = si->currentstaff; curstaff && curbuffernode;
        curstaff = curstaff->next, curbuffernode = curbuffernode->next)
     {
+
+      g_debug ("Current staff %x, Current Staff Next %x,"
+	       " CurBuf %x, CurBuf Next %x\n",
+	       curstaff, curstaff->next, curbuffernode, curbuffernode->next);
+
       curmeasure = g_list_nth (firstmeasurenode (curstaff),
-                               si->currentmeasurenum - 1);
+			       si->currentmeasurenum - 1);
       insertat = initialinsertat;
       for (curbufferobj = (objnode *) curbuffernode->data;
-           curbufferobj && curmeasure; curbufferobj = curbufferobj->next)
-        {
-      /*    if (((mudelaobject *) curbufferobj->data)->type == MEASUREBREAK)
-            {
-
-              curmeasure = curmeasure->next;
-              insertat = 0;
-            }
-			  else*/
-            {
-              clonedobject =
-                clone_object ((mudelaobject *) curbufferobj->data);
-              /*curmeasure->data =
-                g_list_insert ((objnode *) curmeasure->data, clonedobject,
-				  insertat);*/
-				  nextmeasure(si);
-				  object_insert(si, clonedobject);
-              insertat++;
-
-            }
-        }			/* End bufferobj loop */
-      showwhichaccidentalswholestaff ((staff *) curstaff->data);
-      beamsandstemdirswholestaff ((staff *) curstaff->data);
+	   curbufferobj && curmeasure; curbufferobj = curbufferobj->next)
+	{
+	  if (((DenemoObject *) curbufferobj->data)->type == STAFFBREAK)
+	    {
+	      break;
+	    }
+	  else if (((DenemoObject *) curbufferobj->data)->type ==
+		   MEASUREBREAK)
+	    {
+	      /*Do nothing as we will not insert a new barline at 
+		this point. It is done automatically */
+	      g_debug("Have measurebreak object\n");
+	      /*if (!si->currentmeasure->next && si->cursor_appending)
+		/* Add a measure and make it currentmeasure *
+		if (staffsinbuffer == 1)
+		  si->currentmeasure =
+		    dnm_addmeasures (si, si->currentmeasurenum, 1, FALSE);
+		else
+		  si->currentmeasure =
+		    dnm_addmeasures (si, si->currentmeasurenum, 1, TRUE);
+	      else if(si->cursor_appending)
+		si->currentmeasure = si->currentmeasure->next;*/
+	      /*curmeasure = curmeasure->next;*/
+	    }
+	  else
+	    {
+	      g_debug("Paste: Cursor Position %d\n", si->cursor_x);
+	      clonedobject =
+		dnm_clone_object ((DenemoObject *) curbufferobj->data);
+	      
+	      clonedobject->starttick = (si->currentobject?
+					 ((DenemoObject *)si->currentobject->data)->starttickofnextnote: 0);//guess
+	      
+	      g_debug ("offend %d start of next note %d\n", 
+		       si->cursoroffend, clonedobject->starttick);
+	      nextmeasure (si, FALSE);
+	      object_insert(si, clonedobject);
+	      /*	      curmeasure->data =
+	      g_list_insert ((objnode *) curmeasure->data, clonedobject,
+	      insertat);*/
+	      beamandstemdirhelper(si);
+	      
+	      si->cursoroffend = (si->currentobject?
+		((DenemoObject *)si->currentobject->data)->starttickofnextnote
+				  >= (WHOLE_NUMTICKS * si->cursortime1 / si->cursortime2): 0);   // guess  
+	      /*object_insert(si, clonedobject); */
+	      insertat++;
+	    }
+	}			/* End bufferobj loop */
+      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
     }				/* End staff loop */
-  find_xes_in_all_measures (si);
-  nudgerightward (si);
+
   si->haschanged = TRUE;
   si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff),
-                                   si->currentmeasurenum - 1);
+				   si->currentmeasurenum - 1);
   si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
-                                  initialinsertat);
+				  initialinsertat);
   if (!si->currentobject)
     /* Yah. There wasn't anything in the buffer after all. */
     si->cursor_appending = TRUE;
   else
     si->cursor_appending = FALSE;
-  gtk_widget_draw (si->scorearea, NULL);
+  g_debug ("End of Paste Cursor X: %d\n", si->cursor_x);
 }
 
 /**
  *  setmark
  *  Sets the current mark for the start of the buffer
  *
- *  Inputs - struct scoreinfo -  score information
+ *  @param gui pointer to the DenemoGUI structure
  */
 void
-set_mark (struct scoreinfo *si)
+set_mark (DenemoGUI * gui)
 {
+  DenemoScore *si = gui->si;
   si->markstaffnum = si->currentstaffnum;
   si->markmeasurenum = si->currentmeasurenum;
   si->markcursor_x = si->cursor_x;
@@ -418,11 +451,12 @@ set_mark (struct scoreinfo *si)
  * unset_mark
  * Remove the current mark
  *
- * Input - struct scoreinfo - score information
+ * @param gui pointer to the DenemoGUI structure
  */
 void
-unset_mark (struct scoreinfo *si)
+unset_mark (DenemoGUI * gui)
 {
+  DenemoScore *si = gui->si;
   si->markstaffnum = 0;
   calcmarkboundaries (si);
 }
@@ -431,45 +465,41 @@ unset_mark (struct scoreinfo *si)
  *  copywrapper
  *  Wrapper function for the copy command
  *  
- *  Inputs 
- *	data - pointer to the score information
- *	callback_action - unused
- *	widget - unused
+ * @param action pointer to the GTKAction event
+ * @param gui pointer to the DenemoGUI structure
  */
 void
-copywrapper (GtkAction * action, gpointer data)
+copywrapper (GtkAction * action, DenemoGUI * gui)
 {
-  copytobuffer ((struct scoreinfo *) data);
+  copytobuffer (gui->si);
 }
 
 /**
  * cutwrapper
  * Wrapper function for the cut command
  *
- * Inputs 
- *	data - pointer to the score information 
- *	callback_action - unused
- *	widget - unused
+ * @param action pointer to the GTKAction event
+ * @param gui pointer to the DenemoGUI structure 
  */
 void
-cutwrapper (GtkAction * action, gpointer data)
+cutwrapper (GtkAction * action, DenemoGUI * gui)
 {
-  cuttobuffer ((struct scoreinfo *) data);
+  cuttobuffer (gui->si);
+  displayhelper (gui);
 }
 
 /**
  * pastewrapper
  * Wrapper function for the paste command
  *
- * Inputs 
- *	data - pointer to the score information
- *	callback_action - unused
- *	widget - unused
+ * @param gui pointer to the DenemoGUI structure
+ * @param action pointer to the GtkAction event
  */
 void
-pastewrapper (GtkAction * action, gpointer data)
+pastewrapper (GtkAction * action, DenemoGUI * gui)
 {
-  pastefrombuffer ((struct scoreinfo *) data);
+  pastefrombuffer (gui->si);
+  displayhelper (gui);
 }
 
 
@@ -477,15 +507,13 @@ pastewrapper (GtkAction * action, gpointer data)
  * saveselwrapper
  * Wrapper function for the Save selection command
  *
- * Inputs 
- *	data - pointer to the score information
- *	callback_action - unused
- *	widget - unused
+ * @param action pointer to the GtkAction event 
+ * @param gui pointer to the DenemoGUI structure
  */
 void
-saveselwrapper (GtkAction * action, gpointer data)
+saveselwrapper (GtkAction * action, DenemoGUI * gui)
 {
-  saveselection ((struct scoreinfo *) data);
+  saveselection (gui->si);
 }
 
 /**
@@ -494,17 +522,17 @@ saveselwrapper (GtkAction * action, gpointer data)
  * mark
  *
  * Inputs 
- * scoreinfo - score information
- * mark_staff - 
- * mark_measure -
- * mark_object -
- * point_staff -
- * point_measure -
- * point_object -
- * type -
+ * @param si pointer to the DenemoScore structure
+ * @param mark_staff  
+ * @param mark_measure -
+ * @param mark_object -
+ * @param point_staff -
+ * @param point_measure -
+ * @param point_object -
+ * @param type -
  */
 void
-mark_boundaries_helper (struct scoreinfo *si, gint mark_staff,
+mark_boundaries_helper (DenemoScore * si, gint mark_staff,
 			gint mark_measure, gint mark_object, gint point_staff,
 			gint point_measure, gint point_object,
 			enum drag_selection_type type)
@@ -569,7 +597,7 @@ mark_boundaries_helper (struct scoreinfo *si, gint mark_staff,
  * scoreinfo - score information
  */
 void
-calcmarkboundaries (struct scoreinfo *si)
+calcmarkboundaries (DenemoScore * si)
 {
   mark_boundaries_helper (si, si->markstaffnum, si->markmeasurenum,
 			  si->markcursor_x, si->currentstaffnum,
@@ -586,9 +614,10 @@ calcmarkboundaries (struct scoreinfo *si)
  * widget - unused
  */
 void
-undowrapper (GtkAction * action, gpointer data)
+undowrapper (GtkAction * action, DenemoGUI * gui)
 {
-  undo ((struct scoreinfo *) data);
+  undo (gui);
+  displayhelper (gui);
 }
 
 /**
@@ -601,9 +630,10 @@ undowrapper (GtkAction * action, gpointer data)
  * widget - unused
  */
 void
-redowrapper (GtkAction * action, gpointer data)
+redowrapper (GtkAction * action, DenemoGUI * gui)
 {
-  redo ((struct scoreinfo *) data);
+  redo (gui);
+  displayhelper (gui);
 }
 
 
@@ -614,62 +644,57 @@ redowrapper (GtkAction * action, gpointer data)
  * Input
  * scoreinfo - score data
  */
-void
-undo (scoreinfo *si)
+static void
+undo (DenemoGUI * gui)
 {
-  undo_data *undo;
-  redo_data *redo = NULL;
+  unre_data *undo=NULL;
+  unre_data *redo = (unre_data *) g_malloc (sizeof (unre_data));//FIXME memory leak
 
-  //memcpy(redo, undo, sizeof(struct undo)); //Copy undo to redo
-
-
-  if (si->haschanged && si->undo_level > 0)
+  if (gui->si->haschanged && g_queue_get_length (gui->si->undodata) > 0)
     {
-      si->undo_redo_mode = 0;
-      g_print ("List length %d\n", g_queue_get_length(si->undodata));
-      g_print ("Undo Level %d\n", si->undo_level);
-      undo = (undo_data *)g_queue_pop_head (si->undodata);
-		redo = (redo_data *)undo;
-      g_print ("ACtion %d\n", undo->action);
-		si->currentstaffnum = undo->staffnum;
-		si->currentmeasurenum = undo->measurenum;
-		setcurrents (si);
-		si->cursor_x = undo->position;
+      gui->si->undo_redo_mode = UNDO;
+      undo = (unre_data *) g_queue_pop_head (gui->si->undodata);
+      memcpy (redo, undo, sizeof (*undo));
+
+      gui->si->currentstaffnum = undo->staffnum;
+      gui->si->currentmeasurenum = undo->measurenum;
+      setcurrents (gui->si);
+      gui->si->cursor_x = undo->position;
       if (undo->action == ACTION_INSERT)
-        {
-          g_print ("Undo Action Insert:  Remove Object from score\n");
-          g_print ("staffnum %d, measurenum %d, position %d\n",
-                   undo->staffnum, undo->measurenum, undo->position);
-          //      if(((mudelaobject *)undo->object)->type == CHORD) {
-          
-			 setcurrentobject(si,si->cursor_x);
-          g_print ("Position after set_currents %d\n", si->cursor_x);
-          deleteobject (si);
+	{
+	  g_debug ("Undo Action Insert:  Remove Object from score\n");
+	  g_debug ("staffnum %d, measurenum %d, position %d\n",
+		   undo->staffnum, undo->measurenum, undo->position);
 
-           redo->action = ACTION_DELETE;
-          //}
-          g_print ("Done useful");
+	  setcurrentobject (gui->si, gui->si->cursor_x);
 
-        }
+	  g_debug ("Position after set_currents %d\n", gui->si->cursor_x);
+
+	  dnm_deleteobject (gui->si);
+	  /*  redo->action = ACTION_DELETE;*/
+	}
       else if (undo->action == ACTION_DELETE)
-        {
-			  g_print("UNDO Delete Object %d\n", ((mudelaobject *)  undo->object)->type);
-			  object_insert(si, undo->object);
-          g_print ("Do something useful\n");
-        }
+	{
+
+	  object_insert (gui->si, undo->object);
+
+	  g_debug ("UNDO Delete Object %d\n",
+		   ((DenemoObject *) undo->object)->type);
+	  g_debug ("Cursur position before UNDO %d\n", gui->si->cursor_x);
+	  g_debug ("Cursor Position %d\n", gui->si->cursor_x);
+
+	  setcurrents (gui->si);
+	}
       else if (undo->action == ACTION_CHANGE)
-        {
-			 
-			   displayhelper (si);
-          g_print ("Do something useful\n");
-        }
-
-
-      si->undo_level--;
+	{
+	  displayhelper (gui);
+	}
     }
 
-  if (redo)
-    update_redo_info (si, redo);
+  /* update_redo_info (gui->si, redo);*/
+
+  if (undo)
+    g_free (undo);
 }
 
 /**
@@ -680,57 +705,54 @@ undo (scoreinfo *si)
  * scoreinfo - score data
  */
 void
-redo (scoreinfo *si)
+redo (DenemoGUI * gui)
 {
-  g_print ("Redo Level %d\n", si->redo_level);
-  undo_data *undo = NULL;
-  redo_data *redo;
-
-  // memcpy(undo, redo, sizeof(redo)); //Copy undo to redo
-
-
-  if (si->haschanged && si->undo_level > 0)
+  unre_data *undo = NULL;
+  unre_data *redo = NULL;
+  
+  DenemoScore *si = gui->si;
+  if (si->haschanged && g_queue_get_length (si->redodata) > 0)
     {
-      si->undo_redo_mode = 2;
-      g_print ("List length %d\n", g_queue_get_length (si->undodata));
-      g_print ("redo Level %d\n", si->redo_level);
-      redo = (redo_data *) g_queue_pop_head (si->redodata);
-      g_print ("ACtion %d\n", redo->action);
+      si->undo_redo_mode = REDO;
+      redo = (unre_data *) g_queue_pop_head (si->redodata);
+
+      g_debug ("List length %d\n", g_queue_get_length (si->undodata));
+      g_debug ("ACtion %d\n", redo->action);
+
       if (redo->action == ACTION_INSERT)
-        {
-          g_print ("Do something useful\n");
-        }
+	{
+	  si->currentstaffnum = redo->staffnum;
+	  si->currentmeasurenum = redo->measurenum;
+	  si->cursor_x = redo->position;
+	  setcurrents (si);
+
+	  g_debug ("Position after set_currents %d\n", gui->si->cursor_x);
+
+	  dnm_deleteobject (gui->si);
+	}
       else if (redo->action == ACTION_DELETE)
-        {
-          g_print ("Redo Action Insert:  Remove Object from score\n");
-          g_print ("staffnum %d, measurenum %d, position %d\n",
-                   redo->staffnum, redo->measurenum, redo->position);
-          //      if(((mudelaobject *)undo->object)->type == CHORD) {
-          si->currentstaffnum = redo->staffnum;
-          si->currentmeasurenum = redo->measurenum;
-          si->cursor_x = redo->position;
-          setcurrents (si);
-          object_insert (si, (mudelaobject *) redo->object);
+	{
 
-          redo->action = ACTION_DELETE;
-        }
+	  g_debug ("Redo Action Insert:  Remove Object from score\n");
+	  g_debug ("staffnum %d, measurenum %d, position %d\n",
+		   redo->staffnum, redo->measurenum, redo->position);
+
+	  si->currentstaffnum = redo->staffnum;
+	  si->currentmeasurenum = redo->measurenum;
+	  si->cursor_x = redo->position;
+	  setcurrents (si);
+	  object_insert (si, (DenemoObject *) redo->object);
+
+	  redo->action = ACTION_DELETE;
+	}
       else if (redo->action == ACTION_CHANGE)
-        {
-          g_print ("Do something useful\n");
-        }
-
-
-      si->redo_level--;
+	{
+	  g_debug ("Do something useful\n");
+	}
     }
-
-
-  if (undo)
-    update_undo_info (si, undo);
-
-
 }
 
-/** 
+/**
  *  update_undo_info
  *  
  *  Updates the undo list with current operation.
@@ -738,23 +760,21 @@ redo (scoreinfo *si)
  *
  */
 void
-update_undo_info (scoreinfo *si, struct undo_data *undo)
+update_undo_info (DenemoScore * si, unre_data * undo)
 {
-  g_print ("Undo structure: Action %d, Position %d,  Staff %d, Measure %d\n",
-	   undo->action, undo->position, undo->staffnum, undo->measurenum);
+  unre_data *tmp = NULL;
 
-  /*  
-     if(si->undo_level == MAX_UNDOS) {
-     g_list_foreach(si->undodata,freeit ,NULL);
+  g_debug ("Undo structure: Action %d, Position %d,  Staff %d, Measure %d\n",
+	   undo->action, undo->position, undo->staffnum, undo->measurenum); 
+  si->haschanged = TRUE;
 
-     }
-   */
- 
-   if (si->undo_level < MAX_UNDOS && si->haschanged)
+  if (g_queue_get_length (si->undodata) == MAX_UNDOS)
     {
-      g_queue_push_head (si->undodata, undo);
-      si->undo_level++;
+      tmp = g_queue_pop_tail (si->undodata);
     }
+
+  g_queue_push_head (si->undodata, undo);
+  
 }
 
 
@@ -763,25 +783,24 @@ update_undo_info (scoreinfo *si, struct undo_data *undo)
  *  
  *  Updates the redo list with last undo operation.
  *  Is passed score structure and redo_data structure
- *
- *
+ *  @param si pointer to the DenemoScore structure
+ *  @param redo redo data structure to prepend to the queue
  */
 
 void
-update_redo_info (scoreinfo *si, struct redo_data *redo)
+update_redo_info (DenemoScore * si, unre_data * redo)
 {
-  g_print ("Redo structure: Action %d, Position %d,  Staff %d, Measure %d\n",
+  unre_data *tmp = NULL;
+
+  g_debug ("Redo structure: Action %d, Position %d,  Staff %d, Measure %d\n",
 	   redo->action, redo->position, redo->staffnum, redo->measurenum);
 
 
-  if (si->redo_level < MAX_UNDOS && si->haschanged)
+  if (g_queue_get_length (si->redodata) == MAX_UNDOS)
     {
-      g_queue_push_head (si->redodata, redo);
-      si->redo_level++;
+      tmp = g_queue_pop_tail (si->redodata);
+      if (tmp)
+	g_free (tmp);
     }
-  else
-  	{
-  		//g_queue_pop_tail(si->redodata);
-  		g_print("TODO\n");
-  	}
+  g_queue_push_head (si->redodata, redo);
 }
