@@ -1,8 +1,10 @@
-/* staffops.cpp
+/**
+ * staffops.cpp
  * functions dealing with whole staffs
- 
+ *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (c) 1999-2005 Matthew Hiller */
+ * (c) 1999-2005 Matthew Hiller 
+ */
 
 #include "chordops.h"
 #include "contexts.h"
@@ -49,7 +51,7 @@ lastobjnode (measurenode * mnode)
 measurenode *
 firstmeasurenode (staffnode * thestaff)
 {
-  return ((staff *) thestaff->data)->measures;
+  return ((DenemoStaff *) thestaff->data)->measures;
 }
 
 /**
@@ -61,7 +63,7 @@ firstmeasurenode (staffnode * thestaff)
 measurenode *
 nth_measure_node_in_staff (staffnode * thestaff, gint n)
 {
-  return g_list_nth (((staff *) thestaff->data)->measures, n);
+  return g_list_nth (((DenemoStaff *) thestaff->data)->measures, n);
 }
 
 /**
@@ -82,10 +84,10 @@ firstobjnodeinstaff (staffnode * thestaff)
  * @return none
  */
 void
-setcurrentprimarystaff (struct scoreinfo *si)
+setcurrentprimarystaff (DenemoScore * si)
 {
   for (si->currentprimarystaff = si->currentstaff;
-       ((staff *) si->currentprimarystaff->data)->voicenumber != 1;
+       ((DenemoStaff *) si->currentprimarystaff->data)->voicenumber != 1;
        si->currentprimarystaff = si->currentprimarystaff->prev)
     ;
 }
@@ -97,7 +99,7 @@ setcurrentprimarystaff (struct scoreinfo *si)
  * @return none
  */
 static void
-copy_staff_bits (staff * src, staff * dest)
+copy_staff_bits (DenemoStaff * src, DenemoStaff * dest)
 {
   dest->sclef = src->sclef;
   dest->skey = src->skey;
@@ -120,14 +122,14 @@ copy_staff_bits (staff * src, staff * dest)
  * @return none
  */
 static void
-copy_staff_properties(staff *src, staff *dest)
+copy_staff_properties (DenemoStaff * src, DenemoStaff * dest)
 {
   set_lily_name (dest->denemo_name, dest->lily_name);
 
   /* !!!! Insert advisory function for detecting colliding staff names
    * here */
 
-  dest->midi_instrument = g_string_new(src->midi_instrument->str);
+  dest->midi_instrument = g_string_new (src->midi_instrument->str);
   dest->space_above = src->space_above;
   dest->space_below = src->space_below;
   dest->no_of_lines = src->no_of_lines;
@@ -139,6 +141,31 @@ copy_staff_properties(staff *src, staff *dest)
 
 }
 
+/**
+ * Insert a new staff into the score
+ * @param si the scoreinfo structure
+ * @param thestaffstruct the staff to insert
+ * @param action where to insert the new staff
+ * @param addat the position to insert at
+ * @return none
+ */
+static void
+insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct,
+	      enum newstaffcallbackaction action, gint addat)
+{
+  si->thescore = g_list_insert (si->thescore, thestaffstruct, addat - 1);
+  if (action == BEFORE)
+    si->currentstaff = g_list_nth (si->thescore, addat - 1);
+  else
+    si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
+  setcurrentprimarystaff (si);
+  find_leftmost_staffcontext (thestaffstruct, si);
+  g_print ("newstaff: Num staffs after insert %d\n",
+	   g_list_length (si->thescore));
+
+}
+
+
 /**
  * Create and insert a new staff into the score
  * @param si the scoreinfo structure
@@ -147,18 +174,23 @@ copy_staff_properties(staff *src, staff *dest)
  * @return none
  */
 void
-newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontext context)
+newstaff (DenemoScore * si, enum newstaffcallbackaction action,
+	  DenemoContext context)
 {
   g_assert (si != NULL);
   /* What gets added */
-  staff *thestaffstruct = (staff *) g_malloc (sizeof (staff));
+  gint ret = -1;
+  DenemoStaff *thestaffstruct =
+    (DenemoStaff *) g_malloc (sizeof (DenemoStaff));
   struct newstaffinfotopass itp;
   measurenode *themeasures = NULL;	/* Initial set of measures in staff */
   gint numstaffs = g_list_length (si->thescore);
   gint i, n, addat = 1;
   if (si->lily_file)
     return;			/* no code for this yet - just edit textually */
+#ifdef DEBUG
   g_print ("newstaff: Num staffs %d\n", numstaffs);
+#endif
   if (numstaffs == 0)
     {
       action = INITIAL;
@@ -177,19 +209,25 @@ newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontex
       thestaffstruct->space_above = 0;
       thestaffstruct->space_below = 0;
       thestaffstruct->volume = 128;
+      thestaffstruct->nummeasures = 1;
 
       si->measurewidths = g_list_append (si->measurewidths,
-                                         GINT_TO_POINTER (si->measurewidth));
+					 GINT_TO_POINTER (si->measurewidth));
     }
   else
     {
-      n = g_list_length (firstmeasurenode (si->currentstaff));
-      copy_staff_bits ((staff *) si->currentstaff->data, thestaffstruct);
+      /* how did this work before? a new staff must have the same number of
+	 measures as the present one(s) */
+      thestaffstruct->nummeasures = g_list_length (firstmeasurenode (si->thescore));
+      copy_staff_bits ((DenemoStaff *) si->currentstaff->data,
+		       thestaffstruct);
     };
 
   if (action == NEWVOICE)
     {
       thestaffstruct->voicenumber = 2;
+      thestaffstruct->nummeasures =
+	g_list_length (firstmeasurenode (si->currentstaff));
     }
   else if (action == LYRICSTAFF)
     {
@@ -199,12 +237,16 @@ newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontex
     {
       thestaffstruct->voicenumber = 3;	/* what does this mean? */
     }
+  else if (action == CHORDSTAFF)
+    {
+      thestaffstruct->voicenumber = 3;
+    }
   else
     {
       thestaffstruct->voicenumber = 1;
     };
 
-  for (i = 0; i < n; i++)
+  for (i = 0; i < thestaffstruct->nummeasures; i++)
     {
       themeasures = g_list_append (themeasures, NULL);
     };
@@ -223,16 +265,15 @@ newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontex
   thestaffstruct->lily_name = g_string_new (NULL);
   thestaffstruct->context = context;
   if (action == NEWVOICE)
-    /* Fix me to something more reasonable and less prone to collision
-     * with other staff names */
-    g_string_sprintf (thestaffstruct->denemo_name, _("poly voice"));
+    g_string_sprintf (thestaffstruct->denemo_name, _("poly voice %d"),
+		      numstaffs + 1);
   else if (action == LYRICSTAFF)
     g_string_sprintf (thestaffstruct->denemo_name, _("lyrics"));
   else if (action == FIGURESTAFF)
     g_string_sprintf (thestaffstruct->denemo_name, _("figures"));
   else
     g_string_sprintf (thestaffstruct->denemo_name, _("voice %d"),
-                      numstaffs + 1);
+		      numstaffs + 1);
   set_lily_name (thestaffstruct->denemo_name, thestaffstruct->lily_name);
   thestaffstruct->midi_instrument = g_string_new ("acoustic grand");
 
@@ -240,13 +281,14 @@ newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontex
   switch (action)
     {
     case INITIAL:
+      addat = 1;
+      break;
     case LAST:
     case ADDFROMLOAD:
       addat = numstaffs + 1;
       break;
     case BEFORE:
       addat = si->currentstaffnum;
-      si->currentstaffnum++;
       break;
     case AFTER:
     case NEWVOICE:
@@ -254,127 +296,123 @@ newstaff (struct scoreinfo *si, enum newstaffcallbackaction action, denemocontex
     case FIGURESTAFF:
       addat = si->currentstaffnum + 1;
       break;
+    case CHORDSTAFF:
+      addat = si->currentstaffnum + 1;
+      break;
     case FIRST:
       addat = 1;
-      si->currentstaffnum++;
       break;
     }
 
-
-  si->thescore = g_list_insert (si->thescore, thestaffstruct,addat-1);
-  if(action == BEFORE)
-	  si->currentstaff = g_list_nth (si->thescore,addat-1);
-  else
-     si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum-1 /*addat-1*/);
-  setcurrentprimarystaff (si);
-  find_leftmost_staffcontext (thestaffstruct, si);
-  g_print ("newstaff: Num staffs after insert %d\n",
-           g_list_length (si->thescore));
-  itp.si = si;
+  itp.staff = thestaffstruct;
   itp.addat = addat;
   if (action != INITIAL && action != ADDFROMLOAD)
     {
-      if(action == NEWVOICE)
-        {
-          copy_staff_properties((staff *) si->currentstaff->data,thestaffstruct);
-
-          set_bottom_staff (si);
-          find_xes_in_all_measures (si);
-          staffdown(si);
-          gtk_widget_draw (si->scorearea, NULL);
-        }
-      else if (staff_properties_change (NULL, &itp))
-        {
-          // If staff_properties_change returns false,
-          // then the staff should probably be removed
-          // Fixed 09042005 Adam Tee
-
-          set_bottom_staff (si);
-          if (action == BEFORE || action == FIRST)
-            {
-              si->currentstaff = si->currentstaff->next;
-              move_viewport_down (si);
-              staffup(si);
-            }
-          else
-            {
-              update_vscrollbar (si);
-              staffdown(si);
-            }
-				/* setcurrents(si);*/
-          gtk_widget_draw (si->scorearea, NULL);
-        }
+      if (action == NEWVOICE)
+	{
+	  copy_staff_properties ((DenemoStaff *) si->currentstaff->data,
+				 thestaffstruct);
+	  insert_staff (si, thestaffstruct, action, addat);
+	}
       else
-        {
-			 /*Reset current staff to point at the currently inserted staff*/
-			si->currentstaff = g_list_nth(si->thescore, addat-1);
-				
-          removestaff (si, addat-1, 1);
-        }
+	{
+	  ret = staff_properties_change (NULL, &itp);
+
+	  if (ret)
+	    {
+	      /* 
+	         If staff_properties_change returns false,
+	         then the staff should probably be removed
+	         Fixed 09042005 Adam Tee 
+	       */
+	      insert_staff (si, thestaffstruct, action, addat);
+	      si->currentmeasurenum = 1;
+	      /*
+	         Reset leftmeasure num to 1 to be at the start of 
+	         the next staff. 
+	       */
+	      si->leftmeasurenum = 1;
+	    }
+	  else
+	    {
+	      /*
+	       *  Free the staff struct as it has not been inserted 
+	       *  into the score
+	       */
+	      g_free (thestaffstruct);
+	    }
+	}
+    }
+  else
+    {
+      insert_staff (si, thestaffstruct, action, addat);
     }
 
+  //si->haschanged = TRUE;
 }
 
 /**
- * Remove a number of staffs from the score
+ * Remove a number = 1 of staffs from the score
  * @param si the scoreinfo structure
- * @param pos the position of the staff to remove
- * @param numstaffs the number of staffs to remove
+ * @param pos the position of the staff to remove, starting a 0
+ * @param unused numstaffs the number of staffs to remove
  * @return none
  */
 void
-removestaff (struct scoreinfo *si, gint pos, gint numstaffs)
+removestaff (DenemoScore * si, gint pos, gint numstaffs)
 {
   /* The second and third parameters are mostly ignored in this version
    * of the function */
-  staff *curstaffstruct = (staff *) (si->currentstaff ?
-                                     si->currentstaff->data : NULL);
+  DenemoStaff *curstaffstruct = (DenemoStaff *) (si->currentstaff ?
+						 si->currentstaff->
+						 data : NULL);
   if (curstaffstruct)
     {
+      if(g_list_length(si->thescore) < 2 || pos > g_list_length(si->thescore)-1 || pos < 0) /* FIXME do not let these happen - e.g. make DeleteStaffAfter button inactive when on last staff etc */
+	return; 
       gboolean isprimary = ((int) curstaffstruct->voicenumber == 1) ?
-                           TRUE : FALSE;
+	TRUE : FALSE;
       if (si->lily_file != NULL)
-        /* if a lily file, then the objects are freed
-           with the lily tree */
-        g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
+	/* if a lily file, then the objects are freed
+	   with the lily tree */
+	g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
       g_list_free (curstaffstruct->measures);
       g_string_free (curstaffstruct->denemo_name, FALSE);
       g_string_free (curstaffstruct->lily_name, FALSE);
       g_string_free (curstaffstruct->midi_instrument, FALSE);
       if (si->lily_file)
-        {
-          curstaffstruct->measures = NULL;
-          /* don't free the structure as a lily file references it */
-        }
+	{
+	  curstaffstruct->measures = NULL;
+	  /* don't free the structure as a lily file references it */
+	}
       else
-        g_free (curstaffstruct);
+	g_free (curstaffstruct);
       si->thescore = g_list_remove_link (si->thescore, si->currentstaff);
       g_list_free_1 (si->currentstaff);
-      if (pos == (gint) (g_list_length (si->thescore)))
-        {
-          si->currentstaffnum--;
-        };
+      if (pos < si->currentstaffnum)
+	{
+	  if(si->currentstaffnum>1)
+	    si->currentstaffnum--;
+	};
       si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
-
       if (si->currentstaff)
-        {
-          /* O.K.; set si->currentprimarystaff correctly */
-          if (isprimary)
-            {
-              ((staff *) si->currentstaff->data)->voicenumber = 1;
-              si->currentprimarystaff = si->currentstaff;
-            }
-          else
-            {
-              setcurrentprimarystaff (si);
-            };
-        }
+	{
+	  /* O.K.; set si->currentprimarystaff correctly */
+	  if (isprimary)
+	    {
+	      ((DenemoStaff *) si->currentstaff->data)->voicenumber = 1;
+	      si->currentprimarystaff = si->currentstaff;
+	    }
+	  else
+	    {
+	      setcurrentprimarystaff (si);
+	    };
+	}
       else
-        {
-          si->currentprimarystaff = NULL;
-        }
+	{
+	  si->currentprimarystaff = NULL;
+	}
     }
-
 }
 
 /**
@@ -383,7 +421,7 @@ removestaff (struct scoreinfo *si, gint pos, gint numstaffs)
  * @return none
  */
 void
-beamsandstemdirswholestaff (staff * thestaff)
+beamsandstemdirswholestaff (DenemoStaff * thestaff)
 {
   measurenode *curmeasure;
   gint nclef, time1, time2, stem_directive;
@@ -397,7 +435,7 @@ beamsandstemdirswholestaff (staff * thestaff)
        curmeasure = curmeasure->next)
     {
       calculatebeamsandstemdirs ((objnode *) curmeasure->data, &nclef, &time1,
-                                 &time2, &stem_directive);
+				 &time2, &stem_directive);
     }
 }
 
@@ -407,7 +445,7 @@ beamsandstemdirswholestaff (staff * thestaff)
  * @return none
  */
 void
-showwhichaccidentalswholestaff (staff * thestaff)
+showwhichaccidentalswholestaff (DenemoStaff * thestaff)
 {
   gint feed[7];
   gint feednum;
@@ -427,7 +465,7 @@ showwhichaccidentalswholestaff (staff * thestaff)
  * @return none 
  */
 void
-fixnoteheights (staff * thestaff)
+fixnoteheights (DenemoStaff * thestaff)
 {
   gint nclef = thestaff->sclef;
   gint time1 = thestaff->stime1;
@@ -435,32 +473,32 @@ fixnoteheights (staff * thestaff)
   gint initialclef;
   measurenode *curmeasure;
   objnode *curobj;
-  mudelaobject *theobj;
+  DenemoObject *theobj;
 
   for (curmeasure = thestaff->measures; curmeasure;
        curmeasure = curmeasure->next)
     {
       initialclef = nclef;
       for (curobj = (objnode *) curmeasure->data; curobj;
-           curobj = curobj->next)
-        {
-          theobj = (mudelaobject *) curobj->data;
-          switch (theobj->type)
-            {
-            case CHORD:
-              newclefify (theobj, nclef);
-              break;
-            case TIMESIG:
-              time1 = ((timesig *) theobj->object)->time1;
-              time2 = ((timesig *) theobj->object)->time2;
-              break;
-            case CLEF:
-              nclef = ((clef *) theobj->object)->type;
-              break;
-            default:
-              break;
-            }
-        }			/* End for */
+	   curobj = curobj->next)
+	{
+	  theobj = (DenemoObject *) curobj->data;
+	  switch (theobj->type)
+	    {
+	    case CHORD:
+	      newclefify (theobj, nclef);
+	      break;
+	    case TIMESIG:
+	      time1 = ((timesig *) theobj->object)->time1;
+	      time2 = ((timesig *) theobj->object)->time2;
+	      break;
+	    case CLEF:
+	      nclef = ((clef *) theobj->object)->type;
+	      break;
+	    default:
+	      break;
+	    }
+	}			/* End for */
     }				/* End for */
   beamsandstemdirswholestaff (thestaff);
 }
@@ -468,85 +506,133 @@ fixnoteheights (staff * thestaff)
 /**
  * Callback function to insert a staff in the initial position
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstaffinitial (GtkAction * action, gpointer data)
+newstaffinitial (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, INITIAL, DENEMO_NONE);
+  newstaff (gui->si, INITIAL, DENEMO_NONE);
+  set_bottom_staff (gui);
+  displayhelper (gui);
 }
 
 /**
  Callback function to insert a staff before the current staff
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstaffbefore (GtkAction * action, gpointer data)
+newstaffbefore (GtkAction * action, DenemoGUI * gui)
 {
   //  g_print ("New Staff before: score info %X\n", data);
-  newstaff ((struct scoreinfo *) data, BEFORE, DENEMO_NONE);
+  newstaff (gui->si, BEFORE, DENEMO_NONE);
+  set_bottom_staff (gui);
+  move_viewport_down (gui);
+  staffup (gui);
+  displayhelper (gui);
+
 }
 
 /**
  * Callback function to insert a staff after the current staff
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstaffafter (GtkAction * action, gpointer data)
+dnm_newstaffafter (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, AFTER, DENEMO_NONE);
+  newstaff (gui->si, AFTER, DENEMO_NONE);
+  set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  staffdown (gui);
+  displayhelper (gui);
 }
 
 /**
  * Callback function to insert a staff at the bottom of the score
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstafflast (GtkAction * action, gpointer data)
+newstafflast (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, LAST, DENEMO_NONE);
+  newstaff (gui->si, LAST, DENEMO_NONE);
+  set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  staffdown (gui);
+  displayhelper (gui);
 }
 
 /**
  * Callback function to add a new voice to the current staff
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstaffvoice (GtkAction * action, gpointer data)
+dnm_newstaffvoice (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, NEWVOICE, DENEMO_NONE);
+  newstaff (gui->si, NEWVOICE, DENEMO_NONE);
+  set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  staffdown (gui);
+  displayhelper (gui);
 }
 
 /**
  * Callback function to create a lyric staff below the current staff
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstafflyric (GtkAction * action, gpointer data)
+newstafflyric (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, LYRICSTAFF, DENEMO_NONE);
+  newstaff (gui->si, LYRICSTAFF, DENEMO_NONE);
+  set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  staffdown (gui);
+  displayhelper (gui);
 }
 
 
 /**
  * Callback function to insert a figured bass staff after the current staff
  * @param action a Gtk Action
- * @param data the scoreinfo structure
+ * @param gui the DenemoGUI structure
  * @return none
  */
 void
-newstafffigured (GtkAction * action, gpointer data)
+dnm_newstafffigured (GtkAction * action, DenemoGUI * gui)
 {
-  newstaff ((struct scoreinfo *) data, FIGURESTAFF, DENEMO_NONE);
+  newstaff (gui->si, FIGURESTAFF, DENEMO_NONE);
+  set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  staffdown (gui);
+  displayhelper (gui);
 }
+
+
+/*
+ * Callback function to insert chords above the current staff
+ * @param action a Gtk Action
+ * @param gui the DenemoGUI structure
+ * @return none
+ */
+
+void
+dnm_newstaffchords (GtkAction * action, DenemoGUI * gui)
+{
+  printf("\n ok I am going to add chords to the staff now\n");
+  newstaff (gui->si, CHORDSTAFF, DENEMO_NONE);
+  //set_bottom_staff (gui);
+  update_vscrollbar (gui);
+  //staffdown (gui);
+  displayhelper (gui);
+}
+
+
