@@ -10,13 +10,13 @@
 #ifndef UTILS_H
 #define UTILS_H
 
-#include <gtk/gtk.h>
 #include <denemo/denemo.h>
 
 #define LINE_SPACE 10
 #define HALF_LINE_SPACE 5
 #define NO_OF_LINES 5
-#define STAFF_HEIGHT LINE_SPACE * (NO_OF_LINES - 1)
+#define STAFF_HEIGHT (LINE_SPACE * (NO_OF_LINES - 1))
+#define LYRICS_HEIGHT (STAFF_HEIGHT/2)
 #define MID_STAFF_HEIGHT 2*LINE_SPACE
 #define LEFT_MARGIN 20
 #define KEY_MARGIN (LEFT_MARGIN+35)
@@ -75,33 +75,41 @@ gint
 mid_c_offsettooctave (gint mid_c_offset);
 
 void 
-set_grace_numticks(mudelaobject *theobj, gint multiplier);
+set_grace_numticks(DenemoObject *theobj, gint multiplier);
 
 void
-set_tuplefied_numticks (mudelaobject *theobj, gint numerator,
+set_tuplefied_numticks (DenemoObject *theobj, gint numerator,
 			 gint denominator);
 
 void
-set_basic_numticks (mudelaobject *theobj);
+set_basic_numticks (DenemoObject *theobj);
 
 void
-setpixelmin (mudelaobject *theobj);
+setpixelmin (DenemoObject *theobj);
 
 void
 freeit (gpointer data, gpointer user_data);
 
-void 
+void
 warningdialog(gchar *msg);
 
 GtkWidget*
-progressdialog(struct scoreinfo *si);
+progressdialog(DenemoGUI *si);
 
 void 
-headerfields(GtkWidget *dialog, GtkListStore *list_store, GtkTreeIter* iter, struct scoreinfo *si, gboolean isdialog); /* default isdialog shall be TRUE */
+headerfields(GtkWidget *dialog, GtkListStore *list_store, 
+	     GtkTreeIter* iter, DenemoScore *si, gboolean isdialog); 
+/* default isdialog shall be TRUE */
 
 
-void settimesig(staff *curstaffstruct, gint time1, gint time2);
-void setinitialclef(scoreinfo *si, staff *curstaffstruct, enum clefs clef);
-void set_timesig (scoreinfo *si, staff * curstaffstruct, gint time1,
-	  				   gint time2, gboolean all_staves);
-#endif
+void initdir ();
+const gchar *get_data_dir ();
+const gchar *get_plugin_dir ();
+const gchar *get_locale_dir ();
+
+void kill_process (GPid pid);
+
+gchar * music_font(gchar *str);
+
+
+#endif /* UTILS_H */
